@@ -225,7 +225,8 @@ char *path;
     }
 #endif
     
-    strcpy (par_path, path);
+    strncpy (par_path, path, MAXPATHLEN);
+    par_path[MAXPATHLEN] = (char) NULL;
     if (process_cmdline (argc, argv) != TCL_OK)
 	return (TCL_ERROR);
 
@@ -374,7 +375,7 @@ FILE_ENTRY *fe;
     if (S_ISLNK(fe->sb.st_mode)) {
 	strcpy (linkname, " -> ");
 	len = readlink (fe->path, linkname + 4, MAXPATHLEN - 4);
-	*(linkname + 4 + len) = 0;
+	*(linkname + 4 + len) = (char) NULL;
 	return (linkname);
     } else {
 	return (strcpy (linkname, ""));
