@@ -16,13 +16,8 @@
 #define _OT_H
 
 #include <stdlib.h>
-#ifdef HAVE_TCL8_0_H
-#include <tcl8.0.h>
-#include <tk8.0.h>
-#else
 #include <tcl.h>
 #include <tk.h>
-#endif
 
 /* ===== Defines */
 
