@@ -176,7 +176,8 @@ Tk_ImageType tixPixmapImageType = {
     ImgXpmDisplay,		/* displayProc */
     ImgXpmFree,			/* freeProc */
     ImgXpmDelete,		/* deleteProc */
-    (Tk_ImageType *) NULL	/* nextPtr */
+    (Tk_ImagePostscriptProc *) NULL, /* postscriptProc ?? */
+    (struct Tk_ImageType *) NULL /* nextPtr */
 };
 
 /*
@@ -396,7 +397,7 @@ ImgXpmGetData(interp, masterPtr)
     int ncolors;
 
     if (masterPtr->id != NULL) {
-	data = ImgXpmGetDataFromId(interp, masterPtr->id);
+	data = ImgXpmGetDataFromId(interp, (char *) (masterPtr->id));
 	isAllocated = 0;
     }
     else if (masterPtr->fileString != NULL) {
