@@ -1,5 +1,5 @@
 /*
- * $Id: netscape_remote.c,v 1.10 1996/12/12 15:48:11 kenh Exp $
+ * netscape_remote.c,v 1.1.1.1 2004/02/29 21:52:24 jcc Exp
  *
  * netscape_remote - a Tcl/Tk extension to talk the remote command protocol
  *		     that Netscape uses
@@ -25,7 +25,7 @@
 
 #ifndef LINT
 static char rcsid[]=
-	"$Id: netscape_remote.c,v 1.10 1996/12/12 15:48:11 kenh Exp $";
+	"netscape_remote.c,v 1.1.1.1 2004/02/29 21:52:24 jcc Exp";
 #endif
 
 #include "config.h"
