@@ -1274,11 +1274,7 @@ itcl_class dsk_Editor {
 	    paste {
 		set x [lindex $data 0]
 		set y [lindex $data 1]
-		if {[::info proc tkTextClosestGap] != ""} {
-		    set ip [tkTextClosestGap $top.ft.text $x $y]
-		} else {
-		    set ip [$top.ft.text index @$x,$y]
-		}
+	        set ip [$top.ft.text index @$x,$y]
 		set data [lindex $data 2]
 		set selb {}
 		set utype add
