@@ -54,134 +54,119 @@
 #
 
 itcl_class dsk_FileInfo {
+    inherit Toplevel
 
     constructor {args} {
 	global tkdesk
 
-	#
-	# Create a toplevel with this object's name
-	#
-        set class [$this info class]
-        ::rename $this $this-tmp-
-        ::toplevel $this -class $class
-	wm withdraw $this
-        ::rename $this $this-top
-        ::rename $this-tmp- $this
+	if {$tkdesk(tcl_version) < 8.0} {
+	    Toplevel::constructor
+	}
+	
+	wm withdraw $top
 
-	frame $this.fl -bd 1 -relief raised
-	pack $this.fl -fill x
+	frame $top.fl -bd 1 -relief raised
+	pack $top.fl -fill x
 
 	set f [cb_font $tkdesk(font,labels)]
 	catch {set f [join [lreplace [split $f -] 7 7 18] -]}
-	label $this.label -text "$file" -font [cb_font $f]
-	pack $this.label -in $this.fl -side top \
+	label $top.label -text "$file" -font [cb_font $f]
+	pack $top.label -in $top.fl -side top \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
-	frame $this.fi -bd 1 -relief raised
-	pack $this.fi -fill x
+	frame $top.fi -bd 1 -relief raised
+	pack $top.fi -fill x
 
-	frame $this.f1
-	pack $this.f1 -in $this.fi -side left -fill x -anchor n \
+	frame $top.f1
+	pack $top.f1 -in $top.fi -side left -fill x -anchor n \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
-	label $this.lPath -text "Path....:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lSize -text "Size....:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lLink -text "Links...:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lMod  -text "Modified:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lOwn  -text "Owner...:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lGrp  -text "Group...:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lMode -text "Mode....:" -font [cb_font $tkdesk(font,mono)]
-	label $this.lType -text "Type....:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lPath -text "Path....:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lSize -text "Size....:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lLink -text "Links...:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lMod  -text "Modified:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lOwn  -text "Owner...:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lGrp  -text "Group...:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lMode -text "Mode....:" -font [cb_font $tkdesk(font,mono)]
+	label $top.lType -text "Type....:" -font [cb_font $tkdesk(font,mono)]
 
-	pack $this.lPath $this.lSize $this.lMod $this.lOwn \
-		$this.lGrp $this.lMode $this.lLink $this.lType \
-		-in $this.f1 -side top
+	pack $top.lPath $top.lSize $top.lMod $top.lOwn \
+		$top.lGrp $top.lMode $top.lLink $top.lType \
+		-in $top.f1 -side top
 
-	frame $this.f2
-	pack $this.f2 -in $this.fi -side left -fill x \
+	frame $top.f2
+	pack $top.f2 -in $top.fi -side left -fill x \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
-	label $this.lrPath -text "" -font [cb_font $tkdesk(font,mono)]
-	label $this.lrSize -text "" -font [cb_font $tkdesk(font,mono)]
-	label $this.lrLink -text "" -font [cb_font $tkdesk(font,mono)] -height 1
-	button $this.bMod -text "" -font [cb_font $tkdesk(font,mono)] \
+	label $top.lrPath -text "" -font [cb_font $tkdesk(font,mono)]
+	label $top.lrSize -text "" -font [cb_font $tkdesk(font,mono)]
+	label $top.lrLink -text "" -font [cb_font $tkdesk(font,mono)] -height 1
+	button $top.bMod -text "" -font [cb_font $tkdesk(font,mono)] \
 		-command "$this touch" \
 		-padx 1 -pady 1 -highlightthickness 0
-	button $this.bOwn -text "" -font [cb_font $tkdesk(font,mono)] \
+	button $top.bOwn -text "" -font [cb_font $tkdesk(font,mono)] \
 		-command "$this chown" \
 		-padx 1 -pady 1 -highlightthickness 0
-	button $this.bGrp -text "" -font [cb_font $tkdesk(font,mono)] \
+	button $top.bGrp -text "" -font [cb_font $tkdesk(font,mono)] \
 		-command "$this chgrp" \
 		-padx 1 -pady 1 -highlightthickness 0
-	message $this.mMagic -text "" -anchor w \
+	message $top.mMagic -text "" -anchor w \
 		-width 200 -font [cb_font $tkdesk(font,file_lbs)] 
 
-	frame $this.fmod
+	frame $top.fmod
 	for {set i 1} {$i < 10} {incr i} {
-	    button $this.bm($i) -width 2 -font [cb_font $tkdesk(font,mono)] \
+	    button $top.bm($i) -width 2 -font [cb_font $tkdesk(font,mono)] \
 		-command "$this chmod $i" \
 		-padx 1 -pady 1 -highlightthickness 0
 	    # additional button bindings -- added by jdblair, 5.feb.97
-	    bind $this.bm($i) <Button-1> "$this chmod $i; break"
-	    bind $this.bm($i) <Button-2> "$this chmod $i Button-2"
-	    bind $this.bm($i) <Button-3> "$this chmod $i Button-3"
-	    pack $this.bm($i) -in $this.fmod -side left
+	    bind $top.bm($i) <Button-1> "$this chmod $i; break"
+	    bind $top.bm($i) <Button-2> "$this chmod $i Button-2"
+	    bind $top.bm($i) <Button-3> "$this chmod $i Button-3"
+	    pack $top.bm($i) -in $top.fmod -side left
 
 	    if {$i == 3 || $i == 6} {
-		pack [frame $this.fm($i) -width 8] -in $this.fmod -side left
+		pack [frame $top.fm($i) -width 8] -in $top.fmod -side left
 	    }
 	}
 
-	pack $this.lrPath $this.lrSize $this.bMod $this.bOwn \
-		$this.bGrp $this.fmod $this.lrLink $this.mMagic \
-		-in $this.f2 -side top -anchor w
+	pack $top.lrPath $top.lrSize $top.bMod $top.bOwn \
+		$top.bGrp $top.fmod $top.lrLink $top.mMagic \
+		-in $top.f2 -side top -anchor w
 
-	frame $this.fa -bd 1 -relief raised
-	pack $this.fa -fill both -expand yes
+	frame $top.fa -bd 1 -relief raised
+	pack $top.fa -fill both -expand yes
 
-	frame $this.fa1
-	pack $this.fa1 -in $this.fa -fill both -expand yes -pady $tkdesk(pad)
+	frame $top.fa1
+	pack $top.fa1 -in $top.fa -fill both -expand yes -pady $tkdesk(pad)
 
-	label $this.lComment -text "Annotation:" -anchor w
-	pack $this.lComment -in $this.fa1 -fill x -expand no -anchor w \
+	label $top.lComment -text "Annotation:" -anchor w
+	pack $top.lComment -in $top.fa1 -fill x -expand no -anchor w \
 		-padx $tkdesk(pad)
 	
-	cb_text $this.ft -vscroll 1 -lborder 1 -pad $tkdesk(pad) \
+	cb_text $top.ft -vscroll 1 -lborder 1 -pad $tkdesk(pad) \
 		-width 36 -height 6 \
 		-wrap word -setgrid 1
-	pack $this.ft -in $this.fa1 -fill both -expand yes
+	pack $top.ft -in $top.fa1 -fill both -expand yes
 
-	frame $this.fb -bd 1 -relief raised
-	pack $this.fb -fill x
+	frame $top.fb -bd 1 -relief raised
+	pack $top.fb -fill x
 
-	button $this.bClose -text " Close " -command "$this close"
-	button $this.bChmod -text " Change Mode " -state disabled \
+	button $top.bClose -text " Close " -command "$this close"
+	button $top.bChmod -text " Change Mode " -state disabled \
 		-command "$this chmod set"
 
-	pack $this.bClose $this.bChmod -in $this.fb -side left \
+	pack $top.bClose $top.bChmod -in $top.fb -side left \
 		-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 1
 
-	bind $this <Any-Enter> "focus $this.ft.text"
+	bind $top <Any-Enter> "focus $top.ft.text"
 
-	wm title $this "File Information"
-	wm protocol $this WM_DELETE_WINDOW "$this close"
+	wm title $top "File Information"
+	wm protocol $top WM_DELETE_WINDOW "$this close"
 
 	eval config $args
     }
 
     destructor {
-	global tkdesk_anno
-	
-	set anno [string trimright [$this.ft.text get 1.0 end] \n]
-	if {$anno != ""} {
-	    set tkdesk_anno($file) $anno
-	    dsk_refresh $file
-	} elseif [info exists tkdesk_anno($file)] {
-	    unset tkdesk_anno($file)
-	    dsk_refresh $file
-	}
-	#after 10 rename $this-top {}
-        catch {destroy $this}		;# destroy associated window
     }
 
     #
@@ -191,7 +176,7 @@ itcl_class dsk_FileInfo {
     method close {} {
 	global tkdesk_anno
 	
-	set anno [string trimright [$this.ft.text get 1.0 end] \n]
+	set anno [string trimright [$top.ft.text get 1.0 end] \n]
 	if {$anno != ""} {
 	    set tkdesk_anno($file) $anno
 	    dsk_refresh $file
@@ -200,8 +185,12 @@ itcl_class dsk_FileInfo {
 	    dsk_refresh $file
 	}
 
-	wm withdraw $this
-	dsk_FileInfo::cache add $this
+	if {[info tclversion] >= 8.0} {
+	    $this delete
+	} else {
+	    wm withdraw $top
+	    dsk_FileInfo::cache add $this
+	}
     }
 
     method config {config} {
@@ -227,19 +216,29 @@ itcl_class dsk_FileInfo {
     method chown {} {
 	global o
 
+	set as_root 0
 	if {![file owned $file] && ![dsk_is_superuser]} {
-	    dsk_errbell
-	    cb_error "Sorry, you're not the owner of [file tail $file]!"
-	    return
+	    set ret [cb_yesno \
+		    "You're not the owner of [file tail $file].  Try as root?"]
+	    if {$ret == 0} {
+		set as_root 1
+	    } else {
+		return
+	    }
 	}
 
 	set o $owner
 	cb_readString "Change owner of [file tail $file] to:" o "Change Owner"
 	if {$o != ""} {
-	    set err [catch {exec chown $o $file} errmsg]
-	    if $err {
-		cb_error $errmsg
+	    if {!$as_root} {
+		set err [catch {exec chown $o $file} errmsg]
+		if $err {
+		    cb_error $errmsg
+		} else {
+		    $this config -file $file
+		}
 	    } else {
+		dsk_exec_as_root chown $o $file
 		$this config -file $file
 	    }
 	}
@@ -248,19 +247,29 @@ itcl_class dsk_FileInfo {
     method chgrp {} {
 	global g
 
+	set as_root 0
 	if {![file owned $file] && ![dsk_is_superuser]} {
-	    dsk_errbell
-	    cb_error "Sorry, you're not the owner of [file tail $file]!"
-	    return
+	    set ret [cb_yesno \
+		    "You're not the owner of [file tail $file].  Try as root?"]
+	    if {$ret == 0} {
+		set as_root 1
+	    } else {
+		return
+	    }
 	}
 
 	set g $group
 	cb_readString "Change group of [file tail $file] to:" g "Change Group"
 	if {$g != ""} {
-	    set err [catch {exec chgrp $g $file} errmsg]
-	    if $err {
-		cb_error $errmsg
+	    if {!$as_root} {
+		set err [catch {exec chgrp $g $file} errmsg]
+		if $err {
+		    cb_error $errmsg
+		} else {
+		    $this config -file $file
+		}
 	    } else {
+		dsk_exec_as_root chgrp $g $file
 		$this config -file $file
 	    }
 	}
@@ -282,7 +291,7 @@ itcl_class dsk_FileInfo {
 	    return
 	}
 
-	$this.bChmod config -state normal
+	$top.bChmod config -state normal
 
 	for {set i 0} {$i < 10} {incr i} {
 	    set m($i) [string index $fmode $i]
@@ -302,7 +311,7 @@ itcl_class dsk_FileInfo {
 		    if {$cycle == 0} {set cycle 3}
 		    for {set i $cycle} {$i < 10} {incr i 3} {
 			set m($i) $m($num)
-			$this.bm($i) config -text $m($num)
+			$top.bm($i) config -text $m($num)
 	    }
 		}
 	    }
@@ -369,7 +378,7 @@ itcl_class dsk_FileInfo {
   	}
 
 	if {$num != "set"} {
-	    $this.bm($num) config -text $m($num)
+	    $top.bm($num) config -text $m($num)
 	    set fmode ""
 	    for {set i 0} {$i < 10} {incr i} {
 	    	append fmode $m($i)
@@ -415,10 +424,85 @@ itcl_class dsk_FileInfo {
 		cb_error $errmsg
 	    }
 	    dsk_refresh $file
-	    catch {$this.bChmod config -state disabled}
+	    catch {$top.bChmod config -state disabled}
 	}
     }
 
+    method _configFile {} {
+	# backend private proc of the "file" public var
+	global tkdesk tkdesk_anno
+	
+	dsk_busy
+	if [file isdirectory $file] {
+	    set file [string trimright $file "/"]/
+	    set file [dsk_canon_path $file]
+	    if {$file != "/"} {
+		set file [string trimright $file "/"]
+	    }
+	}
+	set n [file tail $file]
+	if [string match $n ""] {set n "/"}
+	$top.label config -text $n
+	set p [file dirname $file]
+	if {[string first $tkdesk(trashdir) $p] == 0} {
+	    set p [string range $p \
+		    [string length $tkdesk(trashdir)/] 1000]
+	    if {$p == ""} {
+		set p "Trash"
+	    }
+	}	
+	$top.lrPath config -text [cb_tilde $p collapse]
+	set lsl ""
+	set lsl [lindex [dskC_ls -l -o $file] 0]
+	#regsub -all {\\t} $lsl "\t" lsl
+	set lsl [split $lsl "\t"]
+	dsk_debug "$file: $lsl"
+	$top.lrSize config -text "[lindex $lsl 1] Bytes"
+	$top.lrLink config -text [string trimleft [lindex $lsl 6] " "]
+	$top.bMod config -text "[lindex $lsl 2]"
+	set owner [lindex $lsl 3]
+	$top.bOwn config -text "$owner"
+	set group [lindex $lsl 4]
+	$top.bGrp config -text "$group"
+
+	set fmode [lindex $lsl 5]
+	for {set i 1} {$i < 10} {incr i} {
+	    $top.bm($i) config -text [string index $fmode $i]
+	}
+
+	set err [catch {set m [exec file $file]} errmsg]
+	if !$err {
+	    $top.mMagic config -text [string trimleft [string range $m \
+		    [expr [string first ":" $m] + 1] 10000] " "]
+	} else {
+	    $top.mMagic config -text $errmsg
+	}
+
+	$top.ft.text delete 1.0 end
+	if [info exists tkdesk_anno($file)] {
+	    $top.ft.text insert end $tkdesk_anno($file)
+	}
+
+	if {[file isdirectory $file] && ![winfo exists $top.bDU]} {
+	    button $top.bDU -text " Disk Usage " -command "dsk_du \"$file\""
+	    pack $top.bDU -in $top.fb -side left \
+			-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 2
+	} else {
+	    if [winfo exists $top.bDU] {
+		destroy $top.bDU
+	    }
+	}
+
+	update idletasks
+	wm iconname $top "Info: [file tail $file]"
+	wm sizefrom $top program
+	if {[wm state $top] != "normal"} {
+	    dsk_place_window $top fileinfo "36x6" 1
+	    wm deiconify $top
+	}
+	dsk_lazy
+    }
+
     proc id {} {
 	set i $id
 	incr id
@@ -450,79 +534,12 @@ itcl_class dsk_FileInfo {
     #
 
     public file "" {
-	global tkdesk tkdesk_anno
 
 	set file [cb_tilde $file expand]
-	if ![file exists $file] {return}
-	dsk_debug "file: $file"	
-
-	dsk_busy
-	if [file isdirectory $file] {
-	    set file [string trimright $file "/"]/
-	    set file [dsk_canon_path $file]
-	    if {$file != "/"} {
-		set file [string trimright $file "/"]
-	    }
+	dsk_debug "dsk_FileInfo config file: $file"	
+	if [file exists $file] {
+	    _configFile
 	}
-	set n [file tail $file]
-	if [string match $n ""] {set n "/"}
-	$this.label config -text $n
-	set p [file dirname $file]
-	if {[string first $tkdesk(trashdir) $p] == 0} {
-	    set p [string range $p \
-		    [string length $tkdesk(trashdir)/] 1000]
-	    if {$p == ""} {
-		set p "Trash"
-	    }
-	}	
-	$this.lrPath config -text [cb_tilde $p collapse]
-	set lsl ""
-	set lsl [lindex [dskC_ls -l -o $file] 0]
-	#regsub -all {\\t} $lsl "\t" lsl
-	set lsl [split $lsl "\t"]
-	dsk_debug "$file: $lsl"
-	$this.lrSize config -text "[lindex $lsl 1] Bytes"
-	$this.lrLink config -text [string trimleft [lindex $lsl 6] " "]
-	$this.bMod config -text "[lindex $lsl 2]"
-	set owner [lindex $lsl 3]
-	$this.bOwn config -text "$owner"
-	set group [lindex $lsl 4]
-	$this.bGrp config -text "$group"
-
-	set fmode [lindex $lsl 5]
-	for {set i 1} {$i < 10} {incr i} {
-	    $this.bm($i) config -text [string index $fmode $i]
-	}
-
-	set err [catch {set m [exec file $file]} errmsg]
-	if !$err {
-	    $this.mMagic config -text [string trimleft [string range $m \
-		    [expr [string first ":" $m] + 1] 10000] " "]
-	} else {
-	    $this.mMagic config -text $errmsg
-	}
-
-	$this.ft.text delete 1.0 end
-	if [info exists tkdesk_anno($file)] {
-	    $this.ft.text insert end $tkdesk_anno($file)
-	}
-
-	if {[file isdirectory $file] && ![winfo exists $this.bDU]} {
-	    button $this.bDU -text " Disk Usage " -command "dsk_du \"$file\""
-	    pack $this.bDU -in $this.fb -side left \
-			-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 2
-	} else {
-	    if [winfo exists $this.bDU] {
-		destroy $this.bDU
-	    }
-	}
-
-	wm iconname $this "Info: [file tail $file]"
-	if {[wm state $this] != "normal"} {
-	    dsk_place_window $this fileinfo "36x6" 1
-	    wm deiconify $this
-	}
-	dsk_lazy
     }
 
     protected owner
@@ -563,13 +580,18 @@ proc dsk_fileinfo {args} {
 	set file [dskC_striptc $file]
 	if ![file exists $file] {
 	    dsk_errbell
-	    cb_info "[file tail $file]\nis a broken symbolic link."
+	    cb_info "[file tail $file]\nis a broken symbolic link or has been removed."
 	    continue
 	}
 	
 	if {$file != ""} {
-	    #dsk_FileInfo .fi[dsk_FileInfo :: id] -file $file
-	    dsk_FileInfo :: cache get -file $file
+	    if {[info tclversion] >= 8.0} {
+		# itcl 3.x seems to disallow object creation through
+		# class procs
+		dsk_FileInfo .fi[dsk_FileInfo :: id] -file $file
+	    } else {
+		dsk_FileInfo :: cache get -file $file
+	    }
 	}
     }
 }
