@@ -51,165 +51,163 @@
 #
 
 itcl_class dsk_HistEntry {
+    inherit Toplevel
 
     constructor {config} {
 	global tkdesk [set this]
 
-	#
-	# Create a toplevel with this object's name
-	# (later accessible as $this-top):
-	#
-        set class [$this info class]
-        ::rename $this $this-tmp-
-        ::toplevel $this -class $class
-	wm withdraw $this
-        ::rename $this $this-top
-        ::rename $this-tmp- $this
+	if {$tkdesk(tcl_version) < 8.0} {
+	    Toplevel::constructor
+	}
+	
+	wm withdraw $top
 
-	frame $this.f -bd 1 -relief raised
-	pack $this.f -fill both -expand yes
+	frame $top.f -bd 1 -relief raised
+	pack $top.f -fill both -expand yes
 
-	frame $this.fl
-	pack $this.fl -in $this.f -fill x
+	frame $top.fl
+	pack $top.fl -in $top.f -fill x
 
-	label $this.label -text $label
-	pack $this.label -in $this.fl -side left \
+	label $top.label -text $label
+	pack $top.label -in $top.fl -side left \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
 	set [set this](cbvar) $checkvalue
 	if {$checklabel != ""} {
-	    checkbutton $this.cbBrowser -text $checklabel \
+	    checkbutton $top.cbBrowser -text $checklabel \
 		    -variable [set this](cbvar)
-	    pack $this.cbBrowser -in $this.fl -side right \
+	    pack $top.cbBrowser -in $top.fl -side right \
 		    -padx $tkdesk(pad) -pady $tkdesk(pad)
 	}
 
-	frame $this.fe
-	pack $this.fe -in $this.f -fill both -expand yes
+	frame $top.fe
+	pack $top.fe -in $top.f -fill both -expand yes
 
-	entry $this.entry -width 40 -bd 2 -relief sunken \
+	entry $top.entry -width 40 -bd 2 -relief sunken \
 		-exportselection no
 	set sel ""
 	if {$entrydefault != ""} {
-	    $this.entry insert end $entrydefault
-	    $this.entry icursor end
-	    $this.entry xview end
+	    $top.entry insert end $entrydefault
+	    $top.entry icursor end
+	    $top.entry xview end
 	} elseif {$history != "" && $sel == ""} {
-	    $this.entry insert end [$history last]
-	    $this.entry icursor end
-	    $this.entry xview end
+	    $top.entry insert end [$history last]
+	    $top.entry icursor end
+	    $top.entry xview end
 	}
 	
-	pack $this.entry -in $this.fe -fill x -expand yes -side left \
+	pack $top.entry -in $top.fe -fill x -expand yes -side left \
 		-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 2
 	
-	bind $this.entry <Visibility> {%W selection range 0 end}
-	bind $this.entry <Return> "$this.bOK.button invoke"
-	bind $this.entry <Escape> "$this.bCancel.button invoke"
-	bind $this.entry <Control-c> "$this.bCancel.button invoke; break"
+	bind $top.entry <Visibility> {%W selection range 0 end}
+	bind $top.entry <Return> "$top.bOK.button invoke"
+	bind $top.entry <Escape> "$top.bCancel.button invoke"
+	bind $top.entry <Control-c> "$top.bCancel.button invoke; break"
+	bind $top.entry <Menu> "$this _entry_popup"
+	bind $top.entry <3> "$this _entry_popup"
 	
-	cb_bindForCompletion $this.entry <Control-Tab>
-	blt_drag&drop target $this.entry handler text \
-		"dd_handle_text $this.entry 1"
+	cb_bindForCompletion $top.entry <Control-Tab>
+	blt_drag&drop target $top.entry handler file \
+		"dd_handle_text $top.entry %v 1"
 
 	if {$history != ""} {
-	    menubutton $this.mbHist -bd 2 -relief raised \
+	    menubutton $top.mbHist -bd 2 -relief raised \
 		    -bitmap @$tkdesk(library)/cb_tools/bitmaps/combo.xbm \
-		    -menu $this.mbHist.menu
-	    pack $this.mbHist -in $this.fe -side right \
+		    -menu $top.mbHist.menu
+	    pack $top.mbHist -in $top.fe -side right \
 		    -padx $tkdesk(pad) -pady $tkdesk(pad) -ipadx 2 -ipady 2
 
-	    menu $this.mbHist.menu -postcommand "$this histmenu"
+	    menu $top.mbHist.menu -postcommand "$this histmenu"
 	    # add dummy entry to work around bug in pre Tk 4.0p2:
-	    $this.mbHist.menu add command -label "dummy"
+	    $top.mbHist.menu add command -label "dummy"
 	    $history changed
 	}
 
-	frame $this.fb -bd 1 -relief raised
-	pack $this.fb -fill x
+	frame $top.fb -bd 1 -relief raised
+	pack $top.fb -fill x
 
-	cb_button $this.bOK -text "   OK   " \
+	cb_button $top.bOK -text "   OK   " \
 		-underline 3 -default 1 -command "
-	    set tkdesk(geometry,hist_entry) \[wm geometry $this\]
-	    set [set this](entry) \[$this.entry get\]
-	    destroy $this
+	    set tkdesk(geometry,hist_entry) \[wm geometry $top\]
+	    set [set this](entry) \[$top.entry get\]
+	    destroy $top
 	    update idletasks
 	    $this ok_pressed
 	"
 
-	cb_button $this.bApply -text " Apply " \
+	cb_button $top.bApply -text " Apply " \
 		-underline 1 -command "
-	    set [set this](entry) \[$this.entry get\]
+	    set [set this](entry) \[$top.entry get\]
 	    $this ok_pressed 0
 	"
 	if $noapply {
-	    $this.bApply.button config -state disabled
+	    $top.bApply.button config -state disabled
 	}
 
 	if {$addbutton != ""} {
 	    set i 0
 	    while {[string index $addbutton $i] == " "} {incr i}
 	    set sc [string index $addbutton $i]
-	    cb_button $this.bAdd -text $addbutton \
+	    cb_button $top.bAdd -text $addbutton \
 		    -underline $i -command "
-	    set tkdesk(geometry,hist_entry) \[wm geometry $this\]
-	    set [set this](entry) \[$this.entry get\]
-	    destroy $this
+	    set tkdesk(geometry,hist_entry) \[wm geometry $top\]
+	    set [set this](entry) \[$top.entry get\]
+	    destroy $top
 	    update idletasks
 	    $this add_pressed
 	    "
-	    cb_addShortcutBinding $this.entry $this.bAdd.button "$sc"
+	    cb_addShortcutBinding $top.entry $top.bAdd.button "$sc"
 	}
 
-	cb_button $this.bCancel -text " Cancel " \
+	cb_button $top.bCancel -text " Cancel " \
 		-underline 1 -command "
-	    set tkdesk(geometry,hist_entry) \[wm geometry $this\]
+	    set tkdesk(geometry,hist_entry) \[wm geometry $top\]
 	    $this delete
 	"
 
-	pack $this.bOK $this.bApply -in $this.fb -side left \
+	pack $top.bOK $top.bApply -in $top.fb -side left \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
 	if {$addbutton != ""} {
-	    pack $this.bAdd -in $this.fb -side left \
+	    pack $top.bAdd -in $top.fb -side left \
 		    -padx $tkdesk(pad) -pady $tkdesk(pad)
 	}
 	
-	pack $this.bCancel -in $this.fb -side left \
+	pack $top.bCancel -in $top.fb -side left \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 
-	cb_addShortcutBinding $this.entry $this.bOK.button "o"
-	cb_addShortcutBinding $this.entry $this.bCancel.button "c"
+	cb_addShortcutBinding $top.entry $top.bOK.button "o"
+	cb_addShortcutBinding $top.entry $top.bCancel.button "c"
 	if !$noapply {
-	    cb_addShortcutBinding $this.entry $this.bApply.button "a"
+	    cb_addShortcutBinding $top.entry $top.bApply.button "a"
 	}
-	bind $this <Any-Enter> "focus $this.entry"
+	bind $top <Any-Enter> "focus $top.entry"
 
-	wm minsize $this 348 117
+	wm minsize $top 348 117
 	if {$title == ""} {
 	    set title $label
 	}
-	wm title $this $title
-	wm protocol $this WM_DELETE_WINDOW "$this.bCancel.button invoke"
+	wm title $top $title
+	wm protocol $top WM_DELETE_WINDOW "$top.bCancel.button invoke"
 
 	if ![info exists tkdesk(geometry,hist_menu)] {
 	    set tkdesk(geometry,hist_menu) ""
 	}
-	dsk_place_window $this hist_entry "" 0 1
-	wm deiconify $this
+	dsk_place_window $top hist_entry "" 0 1
+	wm deiconify $top
 
 	if !$nograb {
-	    grab $this
+	    grab $top
 	    set old_focus [focus]
-	    focus -force $this.entry
-	    tkwait window $this
+	    focus -force $top.entry
+	    tkwait window $top
 	    catch {focus -force $old_focus}
 	}
     }
 
     destructor {
         #after 10 rename $this-top {}		;# delete this name
-        catch {destroy $this}		;# destroy associated window
+        #catch {destroy $this}		;# destroy associated window
     }
 
     #
@@ -244,18 +242,18 @@ itcl_class dsk_HistEntry {
     method histmenu {} {
 	global tkdesk
 
-	catch "$this.mbHist.menu delete 0 last"
+	catch "$top.mbHist.menu delete 0 last"
 	if $tkdesk(sort_history) {
 	    set l [lsort [$history get]]
 	} else {
 	    set l [$history get]
 	}
 	set ne 0
-	set menu $this.mbHist.menu
+	set menu $top.mbHist.menu
 	foreach ent $l {
 	    $menu add command -label $ent \
-		    -command "$this.entry delete 0 end ;\
-		    $this.entry insert end [list $ent]" \
+		    -command "$top.entry delete 0 end ;\
+		    $top.entry insert end [list $ent]" \
 		    -font [cb_font $tkdesk(font,entries)]
 	    incr ne
 	    if {$ne > $tkdesk(_max_menu_entries)} {
@@ -268,6 +266,12 @@ itcl_class dsk_HistEntry {
 	}
     }
 
+    method _entry_popup {} {
+	if {$entrypopupproc != ""} {
+	    $entrypopupproc $top.entry
+	}
+    }
+
     proc id {} {
 	set i $id
 	incr id
@@ -285,6 +289,7 @@ itcl_class dsk_HistEntry {
     public checklabel      ""
     public checkvalue      0
     public entrydefault    ""
+    public entrypopupproc  ""
     public history         ""
     public callback        ""
     public addbutton       ""
