@@ -64,11 +64,6 @@ itcl_class dsk_FileList {
     constructor {args} {
 	global tkdesk env
 	
-	if {$tkdesk(tcl_version) < 8.0} {
-	    Toplevel::constructor
-	    dsk_Common::constructor
-	}
-
 	wm withdraw $top
 	dsk_busy
 
@@ -128,11 +123,7 @@ itcl_class dsk_FileList {
 
 	# --- File Listbox
 	
-	if {$tkdesk(tcl_version) >= 8.0} {
-	    set lbname ::[namespace tail $top.flb]
-	} else {
-	    set lbname $top.flb
-	}
+	set lbname ::[namespace tail $top.flb]
 	dsk_FileListbox $lbname -viewer $this  \
 		-width $tkdesk(file_lb,minwidth) \
 		-height $tkdesk(file_lb,minheight) \
@@ -375,9 +366,11 @@ itcl_class dsk_FileList {
 		}
 	    }
 	    lbmenu {
-		set mb [$lbname getFrame].mb
-		tkMbPost $mb
-		tkMenuFirstEntry $mb.menu
+	        set lbf [$lbname getFrame]
+		set mb $lbf.mb
+		$mb.menu post [winfo rootx $mb] [expr [winfo rooty $mb] + [winfo height $mb]]
+		focus $mb.menu
+		$mb.menu activate 0
 	    }
 	    default {
 		if {$opt == "reverse"} {
