@@ -67,126 +67,125 @@ set tkdesk(config_nostat) 0
 #
 
 itcl_class dsk_FileViewer {
-    inherit dsk_Common
+    inherit dsk_Common Toplevel
     
     constructor {config} {
 	global [set this] tkdesk env cb_tools
 
-	dsk_busy
-	
-	#
-	# Create a toplevel with this object's name
-	# (later accessible as $this-top):
-	#
-        set class [$this info class]
-        ::rename $this $this-tmp-
-        ::toplevel $this -class $class
-        ::rename $this $this-top
-        ::rename $this-tmp- $this
+	if {$tkdesk(tcl_version) < 8.0} {
+	    Toplevel::constructor
+	    dsk_Common::constructor
+	}
 
-	wm withdraw $this
+	wm withdraw $top
+	dsk_busy
 
 	#
 	# Create menubar
 	#
-	frame $this.fMenu -bd 2 -relief raised
-	pack $this.fMenu -fill x
-	_create_menubar $this.fMenu
+	frame $top.fMenu -bd 2 -relief raised
+	pack $top.fMenu -fill x
+	_create_menubar $top.fMenu
 
 	# ---- create button bar
 	if {[llength $tkdesk(button_bar)] > 0} {
 	    if {$tkdesk(pad) > 0} {
-		frame $this.fButtonBar -bd 1 -relief raised
+		frame $top.fButtonBar -bd 1 -relief raised
 	    } else {
-		frame $this.fButtonBar -bd 0 -relief raised
+		frame $top.fButtonBar -bd 0 -relief raised
 	    }
-	    pack $this.fButtonBar -after $this.fMenu -fill x
-	    _create_button_bar $this.fButtonBar
+	    pack $top.fButtonBar -after $top.fMenu -fill x
+	    _create_button_bar $top.fButtonBar
 	}
 	
 	# ---- create path entry
 	if {$tkdesk(pad) > 0} {
-	    frame $this.fPE -bd 1 -relief raised
+	    frame $top.fPE -bd 1 -relief raised
 	} else {
-	    frame $this.fPE -bd 0 -relief raised
+	    frame $top.fPE -bd 0 -relief raised
 	}
-	pack $this.fPE -fill x
+	pack $top.fPE -fill x
 
-	entry $this.ePE -bd 2 -relief sunken
-	bindtags $this.ePE "$this.ePE Entry All"
-	pack $this.ePE -in $this.fPE -side left -fill x -expand yes \
+	entry $top.ePE -bd 2 -relief sunken
+	bindtags $top.ePE "$top.ePE Entry All"
+	pack $top.ePE -in $top.fPE -side left -fill x -expand yes \
 		-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 2
-	bind $this.ePE <Double-1> "[bind Entry <Triple-1>]; break"
-	bind $this.ePE <Any-Enter> {
+	bind $top.ePE <Double-1> "[bind Entry <Triple-1>]; break"
+	bind $top.ePE <Any-Enter> {
 	    if $tkdesk(focus_follows_mouse) {focus %W}
 	}
-	bind $this.ePE <Return> "$this config -dir \[$this.ePE get\]"
-	bind $this.ePE <Control-Return> "set tkdesk(menu,control) 1
-				$this config -dir \[$this.ePE get\]
+	bind $top.ePE <Return> "$this config -dir \[$top.ePE get\]"
+	bind $top.ePE <Control-Return> "set tkdesk(menu,control) 1
+				$this config -dir \[$top.ePE get\]
 				%W delete 0 end
 				%W insert end \[$this curdir\]"
-	bind $this.ePE <Tab> "focus $this; break"
-	bind $this.ePE <3> "update idletasks; $this _path_popup %X %Y"
-	cb_bindForCompletion $this.ePE <Control-Tab>
-	cb_balloonHelp $this.ePE {The path displayed in the current window. Change to visit another directory.\nThe right mouse button gives a popup menu of parent directories.}
-    	blt_drag&drop target $this.ePE \
-				handler text "dd_handle_text $this.ePE 1"
+	bind $top.ePE <Tab> "focus $top; break"
+	bind $top.ePE <3> "update idletasks; $this _path_popup %X %Y"
+	cb_bindForCompletion $top.ePE <Control-Tab>
+	cb_balloonHelp $top.ePE {The path displayed in the current window. Change to visit another directory.  The right mouse button gives a popup menu of parent directories.}
+    	blt_drag&drop target $top.ePE \
+				handler file "dd_handle_text $top.ePE %v 1"
 
-	frame $this.fPE.dis -width $tkdesk(pad)
-	pack $this.fPE.dis -side right
-	menubutton $this.mbHist -bd 2 -relief raised \
+	frame $top.fPE.dis -width $tkdesk(pad)
+	pack $top.fPE.dis -side right
+	menubutton $top.mbHist -bd 2 -relief raised \
 		-bitmap @$tkdesk(library)/cb_tools/bitmaps/combo.xbm \
-		-menu $this.mbHist.menu
-	pack $this.mbHist -in $this.fPE -side right -ipadx 2 -ipady 2
+		-menu $top.mbHist.menu
+	pack $top.mbHist -in $top.fPE -side right -ipadx 2 -ipady 2
 
-	menu $this.mbHist.menu \
-		-postcommand "dir_history buildmenu $this.mbHist.menu ; update"
+	menu $top.mbHist.menu \
+		-postcommand "dir_history buildmenu $top.mbHist.menu ; update"
 	# add dummy entry to work around bug in pre Tk 4.0p2:
-	$this.mbHist.menu add command -label "dummy"
+	$top.mbHist.menu add command -label "dummy"
 	dir_history changed
-	bind $this.mbHist.menu <ButtonRelease-1> "
+	bind $top.mbHist.menu <ButtonRelease-1> "
 		set tkdesk(menu,control) 0
 		[bind Menu <ButtonRelease-1>]"
-	bind $this.mbHist.menu <Control-ButtonRelease-1> "
+	bind $top.mbHist.menu <Control-ButtonRelease-1> "
 		set tkdesk(menu,control) 1
 		[bind Menu <ButtonRelease-1>]"
 
 	# ---- create horizontal scrollbar
 	if {$tkdesk(pad) > 0} {
-	    frame $this.fsb -bd 1 -relief raised
+	    frame $top.fsb -bd 1 -relief raised
 	} else {
-	    frame $this.fsb -bd 0 -relief raised
+	    frame $top.fsb -bd 0 -relief raised
 	}
-	pack $this.fsb -fill x
+	pack $top.fsb -fill x
 	
-	scrollbar $this.hsb -orient horizontal -relief sunken \
+	scrollbar $top.hsb -orient horizontal -relief sunken \
 		-command "$this _set_first_lb"
-	$this.hsb set 1 3 0 2
-	pack $this.hsb -in $this.fsb -fill x \
+	$top.hsb set 1 3 0 2
+	pack $top.hsb -in $top.fsb -fill x \
 		-padx $tkdesk(pad) -pady $tkdesk(pad)
 	
 	#
 	# ---- Create listboxes
 	#
-	frame $this.fLBs
-	pack $this.fLBs -fill both -expand yes
+	frame $top.fLBs
+	pack $top.fLBs -fill both -expand yes
 	set j 0
 	for {set i 0} {$i < $num_lbs} {incr i} {
-	    set lbname $this.lb$j
+	    if {$tkdesk(tcl_version) >= 8.0} {
+		set lbname ::[namespace tail $top.lb$j]
+	    } else {
+		set lbname $top.lb$j
+	    }
 	    incr j
-	    dsk_FileListbox $lbname -viewer $this \
+	    dsk_FileListbox $lbname -viewer $this  \
 		-width $tkdesk(file_lb,minwidth) \
 		-height $tkdesk(file_lb,minheight) -pad $tkdesk(pad)
 	    update idletasks
-	    pack $lbname -in $this.fLBs -side left -fill both -expand yes
+	    set lbname [$lbname getFrame]
+	    pack $lbname -in $top.fLBs -side left -fill both -expand yes
 	    #update
 	    pack propagate $lbname 0
 	}
 	set num_lbs_created $j
 
 	# ---- create status bar
-	frame $this.fStatus -bd [expr $tkdesk(pad) > 0] -relief raised
-	pack [set f $this.fStatus] -fill x
+	frame $top.fStatus -bd [expr $tkdesk(pad) > 0] -relief raised
+	pack [set f $top.fStatus] -fill x
 	label $f.l -anchor w -font [cb_font $tkdesk(font,status)]
 	#	-bd [expr $tkdesk(pad) > 0] -relief sunken
 	#pack $f.l -fill x -padx $tkdesk(pad) -pady $tkdesk(pad)
@@ -196,77 +195,79 @@ itcl_class dsk_FileViewer {
 	#
 	# Bindings
 	#
-	bind $this <Any-Enter> \
+	bind $top <Any-Enter> \
 		"set tkdesk(active_viewer) $this; break"
-	bind $this <Tab> "focus $this.ePE; break"
+	bind $top <Tab> "focus $top.ePE; break"
 
-	bind $this <Control-i> "dsk_fileinfo; break"
-	bind $this <Control-f> "dsk_find_files; break"
-	bind $this <Control-n> "dsk_create file; break"	
-	bind $this <Control-d> "dsk_create directory; break"	
-	bind $this <Control-c> "dsk_copy; break"
-	bind $this <Control-r> "dsk_rename; break"
-	bind $this <Delete> "dsk_delete; break"
-	bind $this <Control-x> "dsk_ask_exec; break"
-	bind $this <Control-e> "dsk_edit; break"
-	bind $this <Control-o> "dsk_ask_dir; break"
-	bind $this <Control-b> "dsk_bookmark add; break"
-	bind $this <Control-p> "dsk_print; break"
-	bind $this <Control-Home> {dsk_cd ~; break}
-	bind $this <Control-Left> {dsk_cd [list [dir_history back]]; break}
-	bind $this <Control-Right> {dsk_cd [list [dir_history forward]]; break}
-	bind $this <Return> "dsk_openall; break"
-	bind $this <F1> "dsk_cbhelp $tkdesk(library)/doc/Guide howto"
-	#bind $this <a><b><o><u><t> dsk_about
+	bind $top <Control-i> "dsk_fileinfo; break"
+	bind $top <Control-f> "dsk_find_files; break"
+	bind $top <Control-n> "dsk_create file; break"	
+	bind $top <Control-d> "dsk_create directory; break"	
+	bind $top <Control-c> "dsk_copy; break"
+	bind $top <Control-r> "dsk_rename; break"
+	bind $top <Delete> "dsk_delete; break"
+	bind $top <Control-x> "dsk_ask_exec; break"
+	bind $top <Control-e> "dsk_edit; break"
+	bind $top <Control-o> "dsk_ask_dir; break"
+	bind $top <Control-b> "dsk_bookmark add; break"
+	bind $top <Control-p> "dsk_print; break"
+	bind $top <Control-w> "dsk_openwith; break"
+	bind $top <Control-Home> {dsk_cd ~; break}
+	bind $top <Control-Left> {dsk_cd [list [dir_history back]]; break}
+	bind $top <Control-Right> {dsk_cd [list [dir_history forward]]; break}
+	bind $top <Return> "dsk_openall; break"
+	bind $top <F1> "dsk_cbhelp $tkdesk(library)/doc/Guide howto"
+	#bind $top <a><b><o><u><t> dsk_about
 
-	bind $this <BackSpace> {dsk_cd ..}
-	bind $this <Up> "$this keynav up"
-	bind $this <Down> "$this keynav down"
-	bind $this <Prior> "$this keynav pgup"
-	bind $this <Next> "$this keynav pgdown"
-	bind $this <Home> "$this keynav first"
-	bind $this <End> "$this keynav last"
-	bind $this <Menu> "$this keynav menu"
+	bind $top <BackSpace> {dsk_cd ..}
+	bind $top <Up> "$this keynav up"
+	bind $top <Down> "$this keynav down"
+	bind $top <Prior> "$this keynav pgup"
+	bind $top <Next> "$this keynav pgdown"
+	bind $top <Home> "$this keynav first"
+	bind $top <End> "$this keynav last"
+	bind $top <Menu> "$this keynav menu"
+	bind $top <F11> "$this keynav lbmenu"
 	foreach l {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-	    bind $this <Key-$l> "$this keynav $l"
-	    bind $this <Shift-$l> "$this keynav $l reverse"
+	    bind $top <Key-$l> "$this keynav $l"
+	    bind $top <Shift-$l> "$this keynav $l reverse"
 	}
 	foreach l {A B C D E F G H I J K L M N O P Q R S T U V W X Y Z} {
-	    bind $this <Key-$l> "$this keynav [string tolower $l] reverse"
-	    #bind $this <Shift-$l> "$this keynav $l"
+	    bind $top <Key-$l> "$this keynav [string tolower $l] reverse"
+	    #bind $top <Shift-$l> "$this keynav $l"
 	}
 
 	#
 	# Window manager settings
 	#
 	update idletasks
-	wm title $this "TkDesk Version $tkdesk(version)"
-	wm minsize $this $tkdesk(file_lb,minwidth) $tkdesk(file_lb,minheight)
-	#wm geometry $this $tkdesk(file_lb,width)x$tkdesk(file_lb,height)
-	dsk_place_window $this fbrowser \
+	wm title $top "TkDesk Version $tkdesk(version)"
+	wm minsize $top $tkdesk(file_lb,minwidth) $tkdesk(file_lb,minheight)
+	#wm geometry $top $tkdesk(file_lb,width)x$tkdesk(file_lb,height)
+	dsk_place_window $top fbrowser \
 		$tkdesk(file_lb,width)x$tkdesk(file_lb,height) 1
-	wm protocol $this WM_DELETE_WINDOW "$this close"
+	wm protocol $top WM_DELETE_WINDOW "$this close"
 
 	if $tkdesk(fvwm) {
 	    # create the icon window
 	    # (this code is based on the code posted by:
 	    # kennykb@dssv01.crd.ge.com (Kevin B. Kenny))
-	    toplevel $this-icon -bg [cb_col $tkdesk(color,icon)] \
+	    toplevel $top-icon -bg [cb_col $tkdesk(color,icon)] \
 		    -class Icon
-	    wm withdraw $this-icon
-	    label $this-icon.label \
+	    wm withdraw $top-icon
+	    label $top-icon.label \
 		    -image [dsk_image $tkdesk(icon,filebrowser)] -bd 0 \
 		    -bg [cb_col $tkdesk(color,icon)]
-	    pack $this-icon.label -ipadx 2 -ipady 2
-	    blt_drag&drop target $this-icon.label handler \
-		    file "$this _dd_drophandler"
+	    pack $top-icon.label -ipadx 2 -ipady 2
+	    blt_drag&drop target $top-icon.label handler \
+		    file "$this _dd_drophandler %v"
 	    update idletasks
-	    wm geometry $this-icon \
-		    [winfo reqwidth $this-icon]x[winfo reqheight $this-icon]
-	    wm protocol $this-icon WM_DELETE_WINDOW "$this delete"
-	    wm iconwindow $this $this-icon
+	    wm geometry $top-icon \
+		    [winfo reqwidth $top-icon]x[winfo reqheight $top-icon]
+	    wm protocol $top-icon WM_DELETE_WINDOW "$this delete"
+	    wm iconwindow $top $top-icon
 	} else {
-	    wm iconbitmap $this @$tkdesk(library)/images/xbm/bigfiling.xbm
+	    wm iconbitmap $top @$tkdesk(library)/images/xbm/bigfiling.xbm
 	}
 	
 	incr count		;# incr the counter of opened fv windows
@@ -282,15 +283,15 @@ itcl_class dsk_FileViewer {
 
 	dsk_sound dsk_new_filebrowser
 	if !$dontmap {
-	    wm deiconify $this
-	    tkwait visibility $this
-	    catch "lower $this .dsk_welcome"
+	    wm deiconify $top
+	    tkwait visibility $top
+	    catch "lower $top .dsk_welcome"
 	    update
 	}
 
 	# the status line may become quite large
-	#pack propagate $this.fStatus 0
-	pack propagate $this 0
+	#pack propagate $top.fStatus 0
+	pack propagate $top 0
 	update
 
 	dsk_lazy
@@ -300,12 +301,10 @@ itcl_class dsk_FileViewer {
 	global tkdesk
 	
 	for {set i 0} {$i < $num_lbs_created} {incr i} {
-	    catch "$this.lb$i delete"
+	    catch "$top.lb$i delete"
 	}
 	incr count -1
-        #after 10 rename $this-top {}	;# delete this name
-        catch {destroy $this}	;# destroy associated windows
-	catch {destroy $this-icon}
+	catch {destroy $top-icon}
 	set tkdesk(active_viewer) ""
 	foreach fv "[itcl_info objects -class dsk_FileViewer] \
 		[itcl_info objects -class dsk_FileList]" {
@@ -367,7 +366,7 @@ itcl_class dsk_FileViewer {
 	#puts "refreshdir: $dir"
 	for {set i 0} {$i < $dir_depth} {incr i} {
 	    if {$lbdirs($i) == $dir} {
-		$this.lb$i refresh
+		$top.lb$i refresh
 		#$this status "Ready."
 		break
 	    }
@@ -380,28 +379,29 @@ itcl_class dsk_FileViewer {
 	# scroll listboxes all to the right:
 	_set_first_lb 1000
 	for {set i 0} {$i < $dir_depth - 1} {incr i} {
-	    $this.lb$i.dlb select clear
-	    $this.lb$i _tag_icons
+	    ::[$top.lb$i getLbObj] select clear
+	    ::$top.lb$i _tag_icons
 	}
 
+	set lb ::[$top.lb$i getLbObj]
 	switch $what {
 	    up {
-		$this.lb[expr $dir_depth -1].dlb select up
+		$lb select up
 	    }
 	    down {
-		$this.lb[expr $dir_depth -1].dlb select down
+		$lb select down
 	    }
 	    pgup {
-		$this.lb[expr $dir_depth -1].dlb select pgup
+		$lb select pgup
 	    }
 	    pgdown {
-		$this.lb[expr $dir_depth -1].dlb select pgdown
+		$lb select pgdown
 	    }
 	    first {
-		$this.lb[expr $dir_depth -1].dlb select first
+		$lb select first
 	    }
 	    last {
-		$this.lb[expr $dir_depth -1].dlb select last
+		$lb select last
 	    }
 	    menu {
 		set file [dsk_active sel]
@@ -409,15 +409,22 @@ itcl_class dsk_FileViewer {
 		    dsk_popup "" $file [winfo pointerx .] [winfo pointery .]
 		}
 	    }
+	    lbmenu {
+	        set lbf [$top.lb$i getFrame]
+		set mb $lbf.mb
+		$mb.menu post [winfo rootx $mb] [expr [winfo rooty $mb] + [winfo height $mb]]
+		focus $mb.menu
+		$mb.menu activate 0
+	    }
 	    default {
 		if {$opt == "reverse"} {
-		    $this.lb[expr $dir_depth -1].dlb select letter $what 1
+		    $lb select letter $what 1
 		} else {
-		    $this.lb[expr $dir_depth -1].dlb select letter $what
+		    $lb select letter $what
 		}
 	    }
 	}
-	$this.lb[expr $dir_depth -1] _tag_icons
+	::$top.lb[expr $dir_depth -1] _tag_icons
     }
 
     method select {cmd args} {
@@ -427,10 +434,17 @@ itcl_class dsk_FileViewer {
 	    get		{# return a list of all selected files
 		set sfl ""
 		for {set i 0} {$i < $dir_depth} {incr i} {
-		    if ![winfo exists $this.lb$i.dlb] continue
-		    set sl [$this.lb$i.dlb select get]
+		    set err [catch {
+			if ![winfo exists [[$top.lb$i getLbObj] getFrame]] {
+			    continue
+			}
+		    } errmsg]
+		    if {$err} {
+			continue
+		    }
+		    set sl [::[$top.lb$i getLbObj] select get]
 		    if {$sl != ""} {
-		        set fl [$this.lb$i.dlb get]
+		        set fl [::[$top.lb$i getLbObj] get]
 			foreach s $sl {
 			    set file [lindex [split [lindex $fl $s] \t] 0]
 			    set file [string trimright $file " "]
@@ -445,8 +459,8 @@ itcl_class dsk_FileViewer {
 	    }
 	    clear	{# clear selection in all listboxes
 		for {set i 0} {$i < $num_lbs_created} {incr i} {
-		    $this.lb$i.dlb select clear
-		    $this.lb$i _tag_icons
+		    ::[$top.lb$i getLbObj] select clear
+		    $top.lb$i _tag_icons
 		}
 		$this selstatus
 	    }
@@ -454,11 +468,11 @@ itcl_class dsk_FileViewer {
 		set sfl [$this select get] 
 		if {$sfl != ""} {
 		    if {$args == "names"} {
-			selection handle $this "$this _retrieve_X_names"
+			selection handle $top "$this _retrieve_X_names"
 		    } else {
-			selection handle $this "$this _retrieve_X"
+			selection handle $top "$this _retrieve_X"
 		    }
-		    selection own $this
+		    selection own $top
 		} else {
 		    cb_info "Please select one or more files first."
 		}
@@ -473,18 +487,18 @@ itcl_class dsk_FileViewer {
 	global tkdesk
 	
 	# lb$num is to become the leftmost listbox
-	#puts "$num, $first_lb, $dir_depth; [$this.hsb get]"
+	#puts "$num, $first_lb, $dir_depth; [$top.hsb get]"
 
 	if $tkdesk(dynamic_scrollbars) {
 	    if {$dir_depth > $num_lbs} {
-		pack $this.fsb -before $this.fLBs -fill x
+		pack $top.fsb -before $top.fLBs -fill x
 	    } else {
-		pack forget $this.fsb
+		pack forget $top.fsb
 	    }
 	}
 
 	if {$first_lb == $num && \
-		$dir_depth == [lindex [$this.hsb get] 0]} return
+		$dir_depth == [lindex [$top.hsb get] 0]} return
 
 	if {$num < 0} {
 	    set num 0
@@ -496,12 +510,12 @@ itcl_class dsk_FileViewer {
 	}
 
 	if {$first_lb == 0 && $num == 0} {
-	    $this.hsb set $dir_depth $num_lbs $first_lb \
+	    $top.hsb set $dir_depth $num_lbs $first_lb \
 				[expr $first_lb + $num_lbs - 1]
 	    return
 	}
 	if {$first_lb == $max_flb && $num == $max_flb} {
-	    $this.hsb set $dir_depth $num_lbs $first_lb \
+	    $top.hsb set $dir_depth $num_lbs $first_lb \
 				[expr $first_lb + $num_lbs - 1]
 	    return
 	}
@@ -510,65 +524,66 @@ itcl_class dsk_FileViewer {
 	#puts "diff: $diff"
 	switch -- $diff {
 	    1 {
-		pack forget $this.lb$first_lb
+		pack forget [$top.lb$first_lb getFrame]
 		if {$num_lbs > 1} {
 		    set i [expr $num + $num_lbs - 1]
-		    pack $this.lb$i \
-			    -after $this.lb[expr $num + $num_lbs - 2] \
-			    -in $this.fLBs -side left -fill both \
+		    pack [$top.lb$i getFrame] \
+			    -after [$top.lb[expr $num + $num_lbs-2] getFrame] \
+			    -in $top.fLBs -side left -fill both \
 			    -expand yes
 		} else {
 		    set i [expr $num + $num_lbs - 1]
-		    pack $this.lb$i \
-			    -in $this.fLBs -side left -fill both \
+		    pack [$top.lb$i getFrame] \
+			    -in $top.fLBs -side left -fill both \
 			    -expand yes
 		}
 		#update idletasks
 		#update
-		pack propagate $this.lb$i 0
+		pack propagate [$top.lb$i getFrame] 0
 	    }
 	    -1 {
-		pack forget $this.lb[expr $first_lb + $num_lbs - 1]
+		pack forget [$top.lb[expr $first_lb + $num_lbs - 1] getFrame]
 		if {$num_lbs > 1} {
-		    pack $this.lb$num \
-			    -before $this.lb$first_lb \
+		    pack [$top.lb$num getFrame] \
+			    -before [$top.lb$first_lb getFrame] \
 			    -side left -fill both \
 			    -expand yes
 		} else {
-		    pack $this.lb$num \
-			    -in $this.fLBs -side left -fill both \
+		    pack [$top.lb$num getFrame] \
+			    -in $top.fLBs -side left -fill both \
 			    -expand yes
 		}
 		#update idletasks
 		#update
-		pack propagate $this.lb$num 0
+		pack propagate [$top.lb$num getFrame] 0
 	    }
 	    default	{
 		for {set i $first_lb} \
 			{$i < [expr $first_lb + $num_lbs]} {incr i} {
-		    pack forget $this.lb$i
+		    pack forget [$top.lb$i getFrame]
 		}
 		for {set i $num} \
 			{$i < [expr $num + $num_lbs]} {incr i} {
-		    pack $this.lb$i \
-			    -in $this.fLBs -side left -fill both \
+		    pack [$top.lb$i getFrame] \
+			    -in $top.fLBs -side left -fill both \
 			    -expand yes
 		    #update idletasks
 		    #update
-		    pack propagate $this.lb$i 0
+		    pack propagate [$top.lb$i getFrame] 0
 		}
 	    }
 	}
 
 	set first_lb $num
-	$this.hsb set $dir_depth $num_lbs $first_lb \
+	$top.hsb set $dir_depth $num_lbs $first_lb \
 				[expr $first_lb + $num_lbs - 1]
 
     }
 
     method _dblclick {lb sel} {
 	global tkdesk
-	
+
+	dsk_debug "Viewer $this, lb $lb, sel $sel"
 	if {$sel == "" || $lb == ""} {
 	    return
 	}
@@ -578,7 +593,8 @@ itcl_class dsk_FileViewer {
 
 	set dir [string trimright [$lb info public directory -value] "/"]
 	#set file [lindex [lindex [$lb.dlb get] [lindex $sel 0]] 0]
-	set file [string trimright [lindex [split [lindex [$lb.dlb get] \
+	set file [string trimright [lindex [split \
+		[lindex [::[$lb getLbObj] get] \
 		[lindex $sel 0]] \t] 0] " "]
 	if $tkdesk(append_type_char) {
 	    set file [dskC_striptc $file]
@@ -586,6 +602,7 @@ itcl_class dsk_FileViewer {
 	if {[string first "/" $file] == -1} {
 	    set file "$dir/$file"
 	}
+	dsk_debug "file $file"
 	if {!$tkdesk(single_click) || \
 		($tkdesk(single_click) && [file isdirectory $file])} {
 	    ::dsk_open $this "$file"
@@ -601,7 +618,8 @@ itcl_class dsk_FileViewer {
 	}
 	set dir [string trimright [$lb info public directory -value] "/"]
 	#set file [lindex [lindex [$lb.dlb get] [lindex $sel 0]] 0]
-	set file [string trimright [lindex [split [lindex [$lb.dlb get] \
+	set file [string trimright [lindex [split \
+		[lindex [::[$lb getLbObj] get] \
 		[lindex $sel 0]] \t] 0] " "]
 	::dsk_popup $lb "$dir/$file" $mx $my
 	#$this selstatus
@@ -612,15 +630,20 @@ itcl_class dsk_FileViewer {
 
 	if {$num_lbs != [set [set this](num_lbs)]} {
 	    dsk_busy
-	    pack propagate $this 1
+	    pack propagate $top 1
 	    if {$num_lbs_created < [set [set this](num_lbs)]} {
 		for {set j $num_lbs_created} \
 			{$j < [set [set this](num_lbs)]} {incr j} {
-	    	    set lbname $this.lb$j
-	    	    dsk_FileListbox $lbname -viewer $this \
+		    if {$tkdesk(tcl_version) >= 8.0} {
+			set lbname ::$top.lb$j
+		    } else {
+			set lbname $top.lb$j
+		    }
+	    	    dsk_FileListbox $lbname -viewer $this  \
 			-width $tkdesk(file_lb,minwidth) -pad $tkdesk(pad)
 		    update
-	    	    pack $lbname -in $this.fLBs -side left \
+		    set lbname [::$lbname getFrame]
+	    	    pack $lbname -in $top.fLBs -side left \
 			-fill both -expand yes
 		    pack propagate $lbname 0
 		}
@@ -630,21 +653,21 @@ itcl_class dsk_FileViewer {
 		if {$num_lbs < [set [set this](num_lbs)]} {
 		    for {set j $num_lbs} \
 			    {$j < [set [set this](num_lbs)]} {incr j} {
-		    	pack $this.lb$j -in $this.fLBs -side left \
+		    	pack [$top.lb$j getFrame] -in $top.fLBs -side left \
 				-fill both -expand yes
 			update
-			pack propagate $this.lb$j 0
+			pack propagate [$top.lb$j getFrame] 0
 		    }
 		} else {
 		    for {set j [set [set this](num_lbs)]} \
 			    {$j < $num_lbs} {incr j} {
-		    	pack forget $this.lb$j
+		    	pack forget [$top.lb$j getFrame]
 		    }
 		}
 	    }
 	    set num_lbs [set [set this](num_lbs)]
 	    update idletasks
-	    pack propagate $this 0
+	    pack propagate $top 0
 	    $this config -directory $directory
 	    dsk_lazy
 	}
@@ -653,24 +676,26 @@ itcl_class dsk_FileViewer {
     method _selecting {lb} {
 	global tkdesk
 
+	dsk_debug "_selecting: lb $lb, num_lbs_created $num_lbs_created"
 	if {$tkdesk(free_selection)} {
 	    return
 	}
 
 	for {set i 0} {$i < $num_lbs_created} {incr i} {
-	    if {"$this.lb$i" != "$lb"} {
-		$this.lb$i.dlb select clear
-		$this.lb$i _tag_icons
+	    if {[string trimleft $top.lb$i :] != [string trimleft $lb :]} {
+		::[$top.lb$i getLbObj] select clear
+		::$top.lb$i _tag_icons
 	    }
 	}
     }
 
-    method _dd_drophandler {} {
-	global DragDrop tkdesk
+    method _dd_drophandler {args} {
+	global tkdesk
 
 	catch "wm withdraw $tkdesk(dd_token_window)"
 	update
 	set dest $directory
+	set flist $args
 
 	if ![file writable $dest] {
 	    dsk_errbell
@@ -682,79 +707,19 @@ itcl_class dsk_FileViewer {
 	    return
 	}
 
-	#dsk_debug "Rec.: $DragDrop(file)"
+	#dsk_debug "Rec.: $flist"
 	#dsk_debug "dest: $dest"
-	dsk_ddcopy $DragDrop(file) $dest
+	dsk_ddcopy $flist $dest
     }
 
     method _button_bar {} {
-	_create_button_bar $this.fButtonBar
+	_create_button_bar $top.fButtonBar
     }
 
-    proc id {{cmd ""}} {
-	if {$cmd == ""} {
-	    set i $id
-	    incr id
-	    return $i
-	} elseif {$cmd == "reset"} {
-	    set id 0
-	    set count 0
-	}
-    }
-
-    #
-    # ----- Variables ---------------------------------------------------------
-    #
-
-    public num_lbs 3
-
-    public dontmap 0
-
-    public dir {} {
-	global tkdesk
-
-	set err [catch {$this-top config}]
-	if !$err {
-	    set err [catch {set isdir [file isdirectory $dir]}]
-	    if !$err {
-		if !$isdir {
-		    if [regexp {\.tar\.gz$|\.tgz$} $dir] {
-			# it's a compressed tar file
-			#set ls_proc {dsk_ls_tar}
-			puts "tar: $dir"
-		    } else {
-			catch {set dir [_make_path_valid $dir]}
-			if ![winfo exists .dsk_welcome] {
-			    # don't want this during startup
-			    catch {dsk_bell}
-			    cb_alert "The path you specified is not completely valid."
-			}
-		    }
-		} elseif ![file readable $dir] {
-		    dsk_errbell
-		    cb_error "[file tail $dir]: Permission denied."
-		    return
-		}
-	    } else {
-		cb_error "Path (or user?) does not exist. Opening home directory."
-		set dir ~
-	    }
-
-	    if $tkdesk(menu,control) {
-		dsk_FileList .dfl[dsk_FileList :: id] -directory $dir
-		set tkdesk(menu,control) 0
-	    } else {
-		$this config -directory $dir
-	    }
-	}
-    }
-
-    public directory "/" {
+    method _configDirectory {} {
+	# backend private proc of public var "directory"
 	global tkdesk env
 
-	if ![winfo exists $this] return
-	dsk_busy
-
 	#set directory "[string trimright [glob $directory] "/"]/"
 	set directory "[string trimright [cb_tilde $directory expand] "/"]/"
 	set directory [dsk_canon_path $directory]
@@ -790,7 +755,7 @@ itcl_class dsk_FileViewer {
 		} elseif {$ndir != $lbdirs($dir_depth)} {
 		    set lbdirs($dir_depth) $ndir
 		} else {
-		    catch {set cmask [$this.lb$first_i cget -mask]}
+		    catch {set cmask [$top.lb$first_i cget -mask]}
 		    incr first_i
 		}
 		incr dir_depth
@@ -809,28 +774,34 @@ itcl_class dsk_FileViewer {
 	#
 	dsk_FileListbox :: print_ready 0
 	for {set i $first_i} {$i < $dir_depth} {incr i} {
-	    if {$i >= $num_lbs_created && ![winfo exists $this.lb$i]} {
-	        dsk_FileListbox $this.lb$i -viewer $this \
+	    if {$i >= $num_lbs_created && ![winfo exists $top.lb$i]} {
+		if {$tkdesk(tcl_version) >= 8.0} {
+		    set lbname ::[namespace tail $top.lb$i]
+		} else {
+		    set lbname $top.lb$i
+		}
+	        dsk_FileListbox $lbname -viewer $this  \
 			-width $tkdesk(file_lb,minwidth) \
 			-height $tkdesk(file_lb,minheight) -pad $tkdesk(pad)
 		update idletasks
 		if {$cmask != ""} {
-		    $this.lb$i set_mask $cmask
+		    $top.lb$i set_mask $cmask
 		}
+		pack propagate [$lbname getFrame] 0
 	    }
 
-	    $this.lb$i config -directory $lbdirs($i)
+	    $top.lb$i config -directory $lbdirs($i)
 	    if {$i > 0} {
-		$this.lb[expr $i - 1] tagpath $lbdirs($i)
+		$top.lb[expr $i - 1] tagpath $lbdirs($i)
 	    }
 	}
-	$this.lb[expr $dir_depth - 1] tagpath
+	$top.lb[expr $dir_depth - 1] tagpath
 
 	if {$i > $num_lbs_created} {
 	    set num_lbs_created $i
 	} else {
 	    while {$i < $num_lbs_created} {
-		$this.lb$i clear
+		$top.lb$i clear
 		incr i
 	    }
 	}
@@ -850,11 +821,11 @@ itcl_class dsk_FileViewer {
 	set last_directory $directory
 
 	# update the path entry:
-	$this.ePE delete 0 end
-	$this.ePE insert end [cb_tilde $directory collapse]
+	$top.ePE delete 0 end
+	$top.ePE insert end [cb_tilde $directory collapse]
 
-	#wm title $this [cb_tilde $directory collapse]
-	#wm iconname $this [file tail [string trimright $directory "/"]]/
+	#wm title $top [cb_tilde $directory collapse]
+	#wm iconname $top [file tail [string trimright $directory "/"]]/
 	set_title
 
 	if !$tkdesk(config_nostat) {
@@ -863,7 +834,82 @@ itcl_class dsk_FileViewer {
 	}
 	dsk_FileListbox :: print_ready 1
 	dsk_status_ready 0
-	dsk_lazy
+    }
+
+    proc id {{cmd ""}} {
+	if {$cmd == ""} {
+	    set i $id
+	    incr id
+	    return $i
+	} elseif {$cmd == "reset"} {
+	    set id 0
+	    set count 0
+	}
+    }
+
+    #
+    # ----- Variables ---------------------------------------------------------
+    #
+
+    public num_lbs 3
+
+    public dontmap 0
+
+    public dir {} {
+	global tkdesk
+
+	set access_ok 1
+	set err [catch {$top config}]
+	if !$err {
+	    set err [catch {set isdir [file isdirectory $dir]}]
+	    if !$err {
+		if !$isdir {
+		    if [regexp {\.tar\.gz$|\.tgz$} $dir] {
+			# it's a compressed tar file
+			#set ls_proc {dsk_ls_tar}
+			puts "tar: $dir"
+		    } else {
+			catch {set dir [_make_path_valid $dir]}
+			if ![winfo exists .dsk_welcome] {
+			    # don't want this during startup
+			    catch {dsk_bell}
+			    cb_alert "The path you specified is not completely valid."
+			}
+		    }
+		} elseif ![file readable $dir] {
+		    dsk_errbell
+		    cb_error "[file tail $dir]: Permission denied."
+		    set access_ok 0
+		}
+	    } else {
+		cb_error "Path (or user?) does not exist. Opening home directory."
+		set dir ~
+	    }
+
+	    if {$access_ok} {
+		if $tkdesk(menu,control) {
+		    if {$tkdesk(tcl_version) >= 8.0} {
+			set lname ::.dfl[dsk_FileList :: id]
+		    } else {
+			set lname .dfl[dsk_FileList :: id]
+		    }
+		    dsk_FileList $lname -directory $dir
+		    set tkdesk(menu,control) 0
+		} else {
+		    $this config -directory $dir
+		}
+	    }
+	}
+    }
+
+    public directory "/" {
+	global tkdesk env
+
+	if {[winfo exists $top]} {
+	    dsk_busy
+	    _configDirectory
+	    dsk_lazy
+	}
     }
 
     protected dir_depth 0	;# depth of the current directory
@@ -878,4 +924,3 @@ itcl_class dsk_FileViewer {
     common id 0
 }
 
-
