@@ -84,7 +84,8 @@ set tkdesk(dont_add_cmd_to_history) 0
 proc dsk_open {viewer file} {
     global tkdesk cmd dsk_open env
 
-    if ![winfo exists $viewer] {
+    dsk_debug "dsk_open: viewer $viewer, file $file"
+    if [catch {$viewer getToplevel}] {
 	set viewer ""
     }
     
@@ -102,9 +103,6 @@ proc dsk_open {viewer file} {
 	return
     }
     
-    #set file [subst -nocommands -novariables [_make_fname_safe $file]]
-    #set file [_make_fname_safe $file]
-
     if [file isdirectory $file] {
 	# DIRECTORY
 
@@ -123,6 +121,7 @@ proc dsk_open {viewer file} {
 	    set file [file dirname $file]
 	}
 
+	dsk_debug "tkdesk(file_lb,control) $tkdesk(file_lb,control), viewer $viewer"
 	if $tkdesk(file_lb,control) {
 	    if $tkdesk(in_browser) {
 		dsk_FileViewer .fv[dsk_FileViewer :: id] \
@@ -132,9 +131,10 @@ proc dsk_open {viewer file} {
 	    }
 	    set tkdesk(file_lb,control) 0
 	} elseif {$viewer != ""} {
-	    #$viewer config -dir "$file"
+	    #puts "$viewer config -dir \"$file\""
 	    set action [dsk_default_action directories $file]
 	    if {$action != ""} {
+		dsk_debug "action $action"
 		eval [_expand_pc $action $file]
 	    }
 	}
@@ -144,7 +144,15 @@ proc dsk_open {viewer file} {
 
 	if !$tkdesk(file_lb,control) {
 	    dsk_busy
-	    set action [dsk_default_action executables $file]
+	    if {$tkdesk(dot_regular)} {
+		if {[file extension $file] == ""} {
+		    set action [dsk_default_action executables $file]
+		} else {
+		    set action [dsk_default_action regulars $file]
+		}
+	    } else {
+		set action [dsk_default_action executables $file]
+	    }
 	    set isf 0
 	    if {$action != ""} {
 		if {$isf} {
@@ -184,6 +192,7 @@ proc dsk_open {viewer file} {
 	    
 	} else {
 	    dsk_busy
+	    update idletasks
 	    set action [dsk_default_action regulars $file]
 	    
 	    if {$action != "" && $action != "-"} {
@@ -191,10 +200,14 @@ proc dsk_open {viewer file} {
 		dsk_history_file $file
 		
 		cd [dsk_active dir]
+		# make TkDesk "lazy" before background execution
+		dsk_lazy
+		
 		eval [_expand_pc $action $file]
 		cd ~
+	    } else {
+		dsk_lazy
 	    }
-	    dsk_lazy
 	}
 
     }
@@ -209,7 +222,8 @@ proc dsk_open {viewer file} {
 
 proc dsk_default_action {popuplist file {matchedvar ""}} {
     global tkdesk
-    
+
+    dsk_debug "dsk_default_action: popuplist $popuplist, file $file, matchedvar $matchedvar"
     if ![info exists tkdesk(popup,$popuplist)] return
     if {$matchedvar != ""} {
 	upvar 1 $matchedvar mpat
@@ -285,6 +299,35 @@ proc dsk_openall {args} {
     return
 }
 
+# ----------------------------------------------------------------------------
+# dsk_openwith files:
+# Asks for command to open $files with.
+
+proc dsk_openwith {{files ""}} {
+    global tkdesk dsk_open
+
+    if {$files == ""} {
+    	set files [dsk_active sel]
+    }
+    
+    if {$files == ""} {
+	dsk_bell
+	cb_info "Please select one or more files first."
+	return
+    }
+
+    set ft {}
+    foreach file $files {
+	lappend ft [_make_fname_safe $file]
+    }
+    set cmd "$dsk_open(lastcmd) $ft"
+    set cmd [dsk_ask_exec $cmd]
+    set tkdesk(file_lb,control) 0
+    set tkdesk(menu,control) 0
+	    
+    return
+}
+
 #
 # -----------------------------------------------------------------------------
 #
@@ -628,7 +671,7 @@ proc dsk_ask_exec_ok {entry val} {
 	set cmd $tmpcmd
 	if {$cmd != ""} {
 	    set dsk_open(lastcmd) [string range $cmd 0 \
-		    [expr [string last " " $cmd] - 1]]
+		    [expr [string first " " $cmd] - 1]]
 	    if {[set og [string first \" $dsk_open(lastcmd)]] > -1} {
 		set dsk_open(lastcmd) [string range $dsk_open(lastcmd) \
 			0 [expr $og - 2]]
@@ -778,6 +821,7 @@ proc dsk_filesel {label filter args} {
     dsk_HistEntry .he[dsk_HistEntry :: id] \
 	    -title "Select A File" \
 	    -entrydefault [string trimright [file dirname $filter] /]/ \
+	    -entrypopupproc dsk_filesel_file_menu \
 	    -label $label \
 	    -history file_history \
 	    -callback dsk_filesel_ok \
@@ -796,6 +840,33 @@ proc dsk_filesel_ok {entry val} {
     return [set dsk_filesel(file) $entry]
 }
 
+proc dsk_filesel_file_menu {entry} {
+
+    set path [$entry get]
+    if {![file isdirectory $path]} {
+	set path [_make_path_valid $path /]
+    }
+    dsk_debug "path: $path"
+
+    if [file isdirectory $path] {
+	set m [winfo toplevel $entry].m
+	catch {destroy $m}
+	menu $m -postcommand "dsk_casdirs [_make_fname_safe $path] $m 1 \"dsk_filesel_menu_cb $entry %d\" 1"
+	
+	update
+	tk_popup $m [winfo pointerx $m] [winfo pointery $m]
+	focus -force $m
+	tkwait window $m
+	update idletasks
+    }
+    
+}
+
+proc dsk_filesel_menu_cb {entry sel} {
+    $entry delete 0 end
+    $entry insert end $sel
+}
+
 proc dsk_filesel_browse {entry val} {
     global tkdesk dsk_filesel
 
@@ -808,10 +879,11 @@ proc dsk_filesel_browse {entry val} {
 	}
     }
 
-    #set dir ""
-    #catch {set dir [file dirname $entry]}
     set dir [_make_path_valid $entry]
+    set file ""
     set isdir 0
+    set err 0
+    
     catch {set isdir [file isdirectory $entry]}
     if $isdir {
 	if {$entry != "/"} {
@@ -827,16 +899,26 @@ proc dsk_filesel_browse {entry val} {
 	    } else {
 		global tk_strictMotif
 
-		#set osm $tk_strictMotif
-		#set tk_strictMotif 0
+		if {$tkdesk(file_selector_type) != "default"} {
+		    set osm $tk_strictMotif
+		    if {$tkdesk(file_selector_type) == "tk"} {
+			set tk_strictMotif 0
+		    } else {
+			set tk_strictMotif 1
+		    }
+		}
 		if $dsk_filesel(saving) {
-		    set file [tk_getSaveFile -title $dsk_filesel(label) \
-			    -initialdir $entry]
+		    set err [catch {set file [tk_getSaveFile \
+			    -title $dsk_filesel(label) \
+			    -initialdir $entry]} errmsg]
 		} else {
-		    set file [tk_getOpenFile -title $dsk_filesel(label) \
-			    -initialdir $entry]
+		    set err [catch {set file [tk_getOpenFile \
+			    -title $dsk_filesel(label) \
+			    -initialdir $entry]} errmsg]
+		}
+		if {$tkdesk(file_selector_type) != "default"} {
+		    set tk_strictMotif $osm
 		}
-		#set tk_strictMotif $osm
 	    }
 	}
     } else {
@@ -852,11 +934,13 @@ proc dsk_filesel_browse {entry val} {
 		#set osm $tk_strictMotif
 		#set tk_strictMotif 0
 		if $dsk_filesel(saving) {
-		    set file [tk_getSaveFile -title $dsk_filesel(label) \
-			    -initialdir $dir]
+		    set err [catch {set file [tk_getSaveFile \
+			    -title $dsk_filesel(label) \
+			    -initialdir $dir]} errmsg]
 		} else {
-		    set file [tk_getOpenFile -title $dsk_filesel(label) \
-			    -initialdir $dir]
+		    set err [catch {set file [tk_getOpenFile \
+			    -title $dsk_filesel(label) \
+			    -initialdir $dir]} errmsg]
 		}
 		#set tk_strictMotif $osm
 	    }
@@ -865,6 +949,10 @@ proc dsk_filesel_browse {entry val} {
     if !$dsk_filesel(use_old_box) {
 	return ""
     } else {
+	if {$err} {
+	    dsk_errbell
+	    cb_error "Error: $errmsg"
+	}
 	return [set dsk_filesel(file) $file]
     }
 }
@@ -911,7 +999,8 @@ proc dsk_cd {{dir ""} {openNew 0}} {
 	}
     }
 
-    if {$dir != "" && [winfo exists $tkdesk(active_viewer)]} {
+    if {$dir != "" && \
+	    [string length [itcl_info objects $tkdesk(active_viewer)]] > 0} {
 	if {![file isdirectory $dir] && $special == ""} {
 	    set dir [_make_path_valid $dir]
 	    catch {dsk_bell}
@@ -1170,18 +1259,6 @@ proc _make_fname_safe {{file ""}} {
     if {$file == ""} {return ""}
 
     set nfile [dskC_esc $file { \"[]{}$;}]
-    #set nfile [string_replace $file \[ \\\[]
-    #set nfile [string_replace $nfile \] \\\]]
-    #set nfile [string_replace $nfile \{ \\\{]
-    #set nfile [string_replace $nfile \} \\\}]
-    #set nfile [string_replace $nfile \$ \\\$]
-    #set nfile [string_replace $nfile \" \\\"]
-    #set nfile [string_replace $nfile " " "\\ "]
-    #set nfile [string_replace $nfile "&" "\\&"]
-    #set nfile [string_replace $nfile "(" "\\("]
-    #set nfile [string_replace $nfile ")" "\\)"]
-
-    #puts $nfile
     return $nfile
 }
 
@@ -1202,6 +1279,7 @@ proc dsk_edit {args} {
 
     set files ""
     set linenum ""
+    set e ""
     foreach f $args {
 	if [regexp {^\+[1-90]+$} $f] {
 	    set linenum $f
@@ -1250,7 +1328,7 @@ proc dsk_edit {args} {
 		if {[string length [$e cget -files]] == 0} {$e delete}
 		#dsk_editor load $files
 	    } else {
-		dsk_editor new
+		set e [dsk_editor new]
 	    }
 	}
     } else {
@@ -1265,7 +1343,21 @@ proc dsk_edit {args} {
 	}
     }
 
-    return
+    return $e
+}
+
+
+proc dsk_edit_wait {args} {
+    set e [eval dsk_edit $args]
+    if {$e != ""} {
+	set ew ""
+	catch {set ew [$e getToplevel]}
+	if {[winfo exists $ew]} {
+	    tkwait window $ew
+	} else {
+	    puts stderr "no such win: $ew"
+	}
+    }
 }
 
 #
@@ -1313,11 +1405,11 @@ proc dsk_msg_alert {msg} {
 }
 
 proc dsk_msg_info {msg} {
-    cb_alert $msg
+    cb_info $msg
 }
 
 proc dsk_msg_error {msg} {
-    cb_alert $msg
+    cb_error $msg
 }
 
 
@@ -1348,9 +1440,10 @@ proc dsk_read_string {msg {script {}} args} {
     if !$dontpaste {
 	catch {set tmpvar [selection get]}
     }
-    if {[string first " " $tmpvar] > -1} {
-	set tmpvar ""
-    }
+    #if {[string first " " $tmpvar] > -1} {
+    #	 set tmpvar ""
+    #}
+    set tmpvar [string trimleft $tmpvar " "]
     set dsk_read_string_script $script
     set dsk_read_string {}
     if {[string length $script] == 0} {
@@ -1371,7 +1464,7 @@ proc dsk_read_string {msg {script {}} args} {
 }
 
 proc dsk_read_string_ok {entry val} {
-    global dsk_read_string dsk_read_string_script
+    global dsk_read_string dsk_read_string_script tkdesk
 
     if {$entry != ""} {
 	update
@@ -1452,10 +1545,13 @@ proc dsk_print {args} {
     set dsk_print(files) $files
     set dsk_print(string) ""
 
-    if [info exists tkdesk(cmd,print)] {
-	set cmd $tkdesk(cmd,print)
-    } else {
-	set cmd "lpr"
+    set cmd [printer_history last]
+    if {$cmd == ""} {
+	if [info exists tkdesk(cmd,print)] {
+	    set cmd $tkdesk(cmd,print)
+	} else {
+	    set cmd "lpr"
+	}
     }
 
     dsk_HistEntry .he[dsk_HistEntry :: id] \
@@ -1515,8 +1611,10 @@ proc dsk_print_ok {entry val} {
     } else {
 	set err [catch {set fd [open "|$cmd" "w"]} errmsg]
 	if !$err {
-	    puts -nonewline $fd $dsk_print(string)
-	    catch {close $fd}
+	    catch {
+		puts -nonewline $fd $dsk_print(string)
+		close $fd
+	    }
 	}
     }
     dsk_lazy
@@ -1569,9 +1667,31 @@ proc dsk_netscape {type {loc ""} {args ""}} {
     }
 
     #puts $cmd
-    set err [catch {send-netscape $cmd}]
+    if [info exists tkdesk(netscapeWinId)] {
+	set err [catch {send-netscape -id $tkdesk(netscapeWinId) $cmd}]
+	if $err {
+	    unset tkdesk(netscapeWinId)
+	    set err [catch {send-netscape -idvar tkdesk(netscapeWinId) $cmd}]
+	}
+    } else {
+	set err [catch {send-netscape -idvar tkdesk(netscapeWinId) $cmd}]
+    }
+    
     if $err {
-	if {[cb_yesno "Netscape is not yet running on your display. Start it now?"] == 0} {
+	set start_netscape 0
+	if {$tkdesk(confirm_netscape)} {
+	    if {[cb_yesno "Netscape doesn't seem to be running yet on your display. Start it now?"] == 0} {
+		set start_netscape 1
+	    }
+	} else {
+	    if {![file exists ~/.netscape/lock]} {
+		set start_netscape 1
+	    } else {
+		puts stderr "tkdesk: Netscape already running"
+	    }
+	}
+	
+	if {$start_netscape} {
 	    # start new netscape
 	    if {$type == "rcmd"} {
 		eval dsk_exec $tkdesk(cmd,netscape) -$loc
