@@ -227,11 +227,7 @@ proc _appbar_create {} {
 	    menu [set m $t.m$count] -disabledforeground blue2
 	    bind $m <ButtonRelease-3> {
 		if {[winfo containing %X %Y] != $dsk_appbar(lastbut)} {
-		    if {[llength [info args tkMenuInvoke]] == 2} {
-			tkMenuInvoke %W 1
-		    } else {
-			tkMenuInvoke %W
-		    }
+		    event generate %W <ButtonRelease-1>
 		}
 		break
 	    }
@@ -631,12 +627,13 @@ proc _appbar_unpost_parents {menu} {
     }
 }
 
-proc _appbar_dd_action {cmd flist} {
+proc _appbar_dd_action {cmd args} {
     global tkdesk
 
     catch "wm withdraw $tkdesk(dd_token_window)"
     update
     
+    set flist $args
     if {[string first %A $cmd] > -1} {
 	set cmd [string_replace $cmd %A $flist]
     } else {
