@@ -19,8 +19,46 @@
 if ![info exists cb_tools(keys_bound)] {
 set cb_tools(keys_bound) 1
 
+if {$tk_version >= 8.4} {
+
+   # Hopefully the use of these will be temporary and we will
+   # find a better way to deal with the effected bindings.
+
+   ::tk::unsupported::ExposePrivateVariable tkPriv
+   ::tk::unsupported::ExposePrivateCommand tkEntryTranspose
+   ::tk::unsupported::ExposePrivateCommand tkTextTranspose
+   ::tk::unsupported::ExposePrivateCommand tkTextPaste
+   ::tk::unsupported::ExposePrivateCommand tkEntryPaste
+   ::tk::unsupported::ExposePrivateCommand tkEntryInsert
+   ::tk::unsupported::ExposePrivateCommand tkTextInsert
+
+}
+
+
 # Make some bindings available even if tk_strictMotif is true:
 #if $tk_strictMotif {}
+
+# Mouse wheel support
+bind Text <Button-5> {%W yview scroll 5 units}
+bind Text <Button-4> {%W yview scroll -5 units}
+bind Text <Shift-Button-5> {%W yview scroll 1 units}
+bind Text <Shift-Button-4> {%W yview scroll -1 units}
+bind Text <Control-Button-5> {%W yview scroll 1 pages}
+bind Text <Control-Button-4> {%W yview scroll -1 pages}
+bind Listbox <Button-5> {%W yview scroll 5 units}
+bind Listbox <Button-4> {%W yview scroll -5 units}
+bind Listbox <Shift-Button-5> {%W yview scroll 1 units}
+bind Listbox <Shift-Button-4> {%W yview scroll -1 units}
+bind Listbox <Control-Button-5> {%W yview scroll 1 pages}
+bind Listbox <Control-Button-4> {%W yview scroll -1 pages}
+bind MouseWheelEnabled <Button-5> {%W yview scroll 5 units}
+bind MouseWheelEnabled <Button-4> {%W yview scroll -5 units}
+bind MouseWheelEnabled <Shift-Button-5> {%W yview scroll 1 units}
+bind MouseWheelEnabled <Shift-Button-4> {%W yview scroll -1 units}
+bind MouseWheelEnabled <Control-Button-5> {%W yview scroll 1 pages}
+bind MouseWheelEnabled <Control-Button-4> {%W yview scroll -1 pages}
+
+
 # Buttons:
 bind Button <Return> "[bind Button <space>]; break"
 bind Checkbutton <Return> [bind Button <space>]
@@ -37,6 +75,7 @@ bind Text <2> {
     set tkPriv(y) %y
     set tkPriv(mouseMoved) 0
 }
+
 bind Text <B2-Motion> {
     if {(%x != $tkPriv(x)) || (%y != $tkPriv(y))} {
 	set tkPriv(mouseMoved) 1
@@ -45,6 +84,7 @@ bind Text <B2-Motion> {
 	%W scan dragto %x %y
     }
 }
+
 bind Text <ButtonRelease-2> {
     if {!$tkPriv(mouseMoved)} {
 	catch {
@@ -61,6 +101,7 @@ bind Text <ButtonRelease-2> {
 	%W see insert
     }
 }
+
 bind Text <Control-k> {
     if [%W compare insert == {insert lineend}] {
 	%W delete insert
@@ -493,3 +534,4 @@ proc cb_addShortcutBinding {widget button char args} {
     bind $widget <Meta-$char> [bind $widget <Alt-$char>]
     bind $widget <Control-$char> [bind $widget <Alt-$char>]
 }
+
