@@ -153,11 +153,11 @@ proc cb_readString {e_label {e_var cb_readString(tmp)} {title ""} \
 
     	grab $t
 	set old_focus [focus]
-	catch {focus -force $t.eEntry}
-
-    	tkwait window $t
-
-	catch {focus -force $old_focus}
+	catch {
+	    focus -force $t.eEntry
+	    tkwait window $t
+	    focus -force $old_focus
+	}
 	return [set $e_var]
 }
 
@@ -535,10 +535,8 @@ proc cb_balloonHelp {w text {delay 500}} {
     set cb_balloonHelp($w,shown) 0
 
     if {$me == ""} {
-	bind $w <Enter> "
-	set cb_balloonHelp(id) \
-		\[after $delay _cb_balloonDisplay $w \\\{$text\\\} %X %Y\]
-	"
+	bind $w <Enter> "+set cb_balloonHelp(id) \
+		\[after $delay _cb_balloonDisplay $w \\\{$text\\\} %X %Y\]"
 	#bind $w <Motion> "
 	#set tmp_w \[winfo containing %X %Y\]
         #catch \{destroy .cb_balloon\}
@@ -615,35 +613,34 @@ proc _cb_balloonDisplay {w text rx ry} {
     #	 set cb_tools(no_balloon) 0
     #	 return
     #}
-    if {!$cb_tools(balloon_help) || $cb_balloonHelp($w,shown)} {
-	return
+    if {$w != ""} {
+	if {!$cb_tools(balloon_help) || $cb_balloonHelp($w,shown)} {
+	    return
+	}
+	if {[winfo containing [winfo pointerx .] [winfo pointery .]] != $w} {
+	    return
+	}
+	set cb_balloonHelp($w,shown) 1
     }
-    if {[winfo containing [winfo pointerx .] [winfo pointery .]] != $w} {
-	return
-    }
-    set cb_balloonHelp($w,shown) 1
     
     catch {destroy [set t .cb_balloon]}
     toplevel $t -bg yellow
     wm withdraw $t
-    label $t.l -text $text -wraplength 200 -justify left \
+    label $t.l -text $text -wraplength 300 -justify left \
 	    -bg \#ffffa8 -fg black -bd 1 -relief flat -padx 2 -pady 2 \
 	    -highlightbackground black -highlightcolor black \
-	    -highlightthickness 1
+	    -highlightthickness 1 -cursor top_left_arrow
     set err [catch {$t.l config -font [cb_font $tkdesk(font,balloon)]}]
     if $err {$t.l config -font fixed}
     pack $t.l
     wm overrideredirect $t 1
-    #set x [expr $rx + 2]
-    #set y [expr $ry - [winfo reqheight $t.l] - 2]
-    #set x [expr $rx + 8]
-    #set y [expr $ry + 16]
-    #set x [expr [winfo rootx $w] + [winfo width $w] + 2]
-    #set y [expr [winfo rooty $w] + [winfo height $w] + 2]
-    #set x [winfo rootx $w]
-    set x [winfo pointerx $w]
-    #set y [expr [winfo rooty $w] + [winfo height $w]]
-    set y [expr [winfo pointery $w] + 16]
+    if {$w != ""} {
+	set x [winfo pointerx $w]
+	set y [expr [winfo pointery $w] + 16]
+    } else {
+	set x $rx
+	set y $ry
+    }
     if {$y < 0} {set y 0}
     set w [winfo reqwidth $t.l]
     set h [winfo reqheight $t.l]
@@ -664,6 +661,7 @@ proc _cb_balloonDisplay {w text rx ry} {
     # remove the balloon window after 5 seconds:
     set cb_balloonHelp(id,timeout) \
         [after [expr 5000 + [string length $text] * 50] "catch \{destroy $t\}"]
+    return $t
 }
 
 # --------------------------------------------------------------------------
