@@ -68,7 +68,7 @@ set cb_tools(restarting) 0
 #	devel	Set to 1 if working on the cb-tools (internal).
 #
 
-proc cb_tools_init {{path ""} {devel 0}} {
+proc cb_tools_init {{path ""} {devel 0} {do_source 0}} {
     global cb_tools auto_path
 
     option add *Scrollbar.highlightThickness 0
@@ -91,7 +91,7 @@ proc cb_tools_init {{path ""} {devel 0}} {
     # And now source the appropriate files:
     #
 
-    if {!$devel} {
+    if {!$do_source} {
         lappend auto_path $cb_tools(path)
         
 	# this has always to be sourced so that 
@@ -218,17 +218,10 @@ proc cb_tilde {path {mode "normal"}} {
 	}
 	return $rpath
     } elseif {$mode != "expand"} {
-	set hp [string first $env(HOME) $path]
-	if {$hp == 0 && ![string match $env(HOME) "/"]} {
-	    # check whether HOME's like "/home/user/" as opposed to
-	    # "/home/user"
-	    if {[string index $env(HOME) \
-		    [expr [string length $env(HOME)] -1 ]] \
-		    == "/"} {
-		set path ~/[string range $path [string length $env(HOME)] end]
-	    } else {
-		set path ~[string range $path [string length $env(HOME)] end]
-	    }
+	set home [string trimright $env(HOME) "/"]/
+	set hp [string first $home $path]
+	if {$hp == 0 && ![string match $home "/"]} {
+	    set path ~/[string range $path [string length $home] end]
 	}
 	return $path
     } else {
@@ -353,6 +346,7 @@ proc cb_BusyCursor {{others ""}} {
 
     if [info exists cb_tools(busy_cmd)] {
 	$cb_tools(busy_cmd)
+	return
     }
     
     set window .
@@ -380,6 +374,7 @@ proc cb_NormalCursor {{others ""}} {
     
     if [info exists cb_tools(lazy_cmd)] {
 	$cb_tools(lazy_cmd)
+	return
     }
 
     set window .
@@ -752,15 +747,15 @@ proc cb_font {font {fallback ""}} {
 # Arranges for $sec to be withdrawn whenever $prim get unmapped
 # (or iconified), and to be remapped when $prim is remapped.
 #
-proc cb_manage_secondary {prim sec} {
-    bind $prim <Unmap> "\
-	    if \{\"%W\" == \"$prim\"\} \{ \
-	       if \[winfo exists $sec\] \{wm withdraw $sec\} \
-	    \}"
-    bind $prim <Map> "\
-	    if \{\"%W\" == \"$prim\"\} \{ \
-	       if \[winfo exists $sec\] \{wm deiconify $sec\} \
-	    \}"
+proc cb_manage_secondary {prim args} {
+    foreach sec $args {
+	bind $prim <Unmap> "+if \{\"%W\" == \"$prim\"\} \{ \
+		    if \[winfo exists $sec\] \{wm withdraw $sec\} \
+		\}"
+	bind $prim <Map> "+if \{\"%W\" == \"$prim\"\} \{ \
+		    if \[winfo exists $sec\] \{wm deiconify $sec\} \
+		\}"
+    }
 }
 
 # ---------------------------------------------------------------------------
