@@ -471,6 +471,7 @@ proc read_System {} {
     option add *Menubutton.font [cb_font $tkdesk(font,menubuttons)]
     option add *Menu.font [cb_font $tkdesk(font,menus)]
     option add *Listbox.font [cb_font $tkdesk(font,listboxes)]
+    option add *Dialog.msg.font [cb_font $tkdesk(font,dialogs)]
 
     _cb_help_proc:setfont \
 	    [cb_font $tkdesk(font,entries)] \
@@ -617,7 +618,7 @@ set tkdesk(tkdesk_server) 0     ;# start TkDesk server
 set tkdesk(list_statbar) 0      ;# display status bar in file list windows?
 set tkdesk(tearoff-menus) 0     ;# 1 if menus should be tear-off-able
 set tkdesk(focus_follows_mouse) 1   ;# focus model to use
-set tkdesk(strict_motif) 1      ;# strict Motif look-and-feel?
+set tkdesk(strict_motif) 0      ;# strict Motif look-and-feel?
 set tkdesk(auto_reload_conf) 1  ;# automatically reload modified conf files?
 set tkdesk(expand_dir_bookmarks) 1  ;# expand dirs in Bookmarks menu?
 set tkdesk(confirm_netscape) 1    ;# ask whether to start Netscape?
@@ -1507,35 +1508,36 @@ proc dsk_reread_config {{cfgfile ""}} {
     # Reread all config files:
     #
 
-    foreach obj [itcl_info objects -class dsk_Editor] {
-	if {[$obj close_win] == "cancel"} {
-	    return
-	}
-    }
+#    foreach obj [itcl_info objects -class dsk_Editor] {
+#	if {[$obj close_win] == "cancel"} {
+#	    return
+#	}
+#    }
+#
+#    dsk_busy
+#
+#    dsk_save_config
+#    dsk_status "Rereading configuration..."
+#    dsk_read_config
+#
+#    dsk_debug "Deleting old windows..."
+#    foreach class {dsk_FileViewer dsk_FileList} {
+#	foreach obj [itcl_info objects -class $class] {
+#	    $obj delete
+#	}
+#	$class :: id reset
+#    }
+#    dsk_Editor :: id reset
+#    foreach topname {dsk_ask_exec dsk_ask_dir dsk_jobs dsk_copy \
+#		dsk_delete dsk_appbar dsk_find_annotation} {
+#	catch "destroy .$topname"
+#    }
+#
+#    dsk_restore_layout
+#
+#    dsk_lazy
+#    return
 
-    dsk_busy
-
-    dsk_save_config
-    dsk_status "Rereading configuration..."
-    dsk_read_config
-
-    dsk_debug "Deleting old windows..."
-    foreach class {dsk_FileViewer dsk_FileList} {
-	foreach obj [itcl_info objects -class $class] {
-	    $obj delete
-	}
-	$class :: id reset
-    }
-    dsk_Editor :: id reset
-    foreach topname {dsk_ask_exec dsk_ask_dir dsk_jobs dsk_copy \
-		dsk_delete dsk_appbar dsk_find_annotation} {
-	catch "destroy .$topname"
-    }
-
-    dsk_restore_layout
-
-    dsk_lazy
-    return
 }
 
 #
