@@ -104,7 +104,7 @@ proc dsk_copy {{files ""} {dest ""}} {
     bind $t.eFile <3> {dsk_popup %W [%W get] %X %Y}
     cb_bindForCompletion $t.eFile <Control-Tab>
 
-    blt_drag&drop target $t.eFile handler text "dd_handle_text $t.eFile 1"
+    blt_drag&drop target $t.eFile handler file "dd_handle_text $t.eFile %v 1"
 
     label $t.lFile
     if {$files == ""} {
@@ -144,7 +144,7 @@ proc dsk_copy {{files ""} {dest ""}} {
     bind $t.eDest <Return> "dsk_copy_action copy"
     cb_bindForCompletion $t.eDest <Control-Tab>
 
-    blt_drag&drop target $t.eDest handler text "dd_handle_text $t.eDest 1"
+    blt_drag&drop target $t.eDest handler file "dd_handle_text $t.eDest %v 1"
 
     label $t.lDest -text "Destination:"
     pack $t.lDest -in $t.fdf -side left
@@ -190,11 +190,15 @@ proc dsk_copy {{files ""} {dest ""}} {
 	    -bd 2 -relief raised 
     menu $m
     foreach me $tkdesk(fileops,popup) {
-	set l [lindex $me 0]
-	set c [lindex $me 1]
-	$m add command -label $l -command "set dsk_copy_other [list $l]"
-	if {$dsk_copy_other == ""} {
-	    set dsk_copy_other $l
+	if {$me == "-"} {
+	    $m add separator
+	} else {
+	    set l [lindex $me 0]
+	    set c [lindex $me 1]
+	    $m add command -label $l -command "set dsk_copy_other [list $l]"
+	    if {$dsk_copy_other == ""} {
+		set dsk_copy_other $l
+	    }
 	}
     }
 
@@ -202,7 +206,6 @@ proc dsk_copy {{files ""} {dest ""}} {
 		set dsk_copy(ldest) [.dsk_copy.eDest get]
 		set tkdesk(geometry,dsk_copy) [wm geometry .dsk_copy]
 		destroy .dsk_copy }
-
     pack $t.bCancel -in $t.fb -side right \
 		-padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 1
 		
@@ -220,6 +223,8 @@ proc dsk_copy {{files ""} {dest ""}} {
 
     #bind $t <Any-Enter> "+focus $t.eFile"
     #focus $t.eFile
+    bind $t.eFile <Escape> "$t.bCancel.button invoke"
+    bind $t.eDest <Escape> "$t.bCancel.button invoke"
 
     wm minsize $t 486 167
     wm title $t "Copy, Move, Link Files"
@@ -234,6 +239,9 @@ proc dsk_copy_dest_popup {entry x y} {
     global tkdesk
     
     set dest [$entry get]
+    if {![file isdirectory $dest]} {
+	set dest [_make_path_valid $dest /]
+    }
     if [file isdirectory $dest] {
 	set this .dsk_copy
 	set m $this-ppop
@@ -265,7 +273,7 @@ proc dsk_copy_dest_popup {entry x y} {
 		$m add cascade -label $p -menu $cm -font [cb_font $tkdesk(font,file_lbs)]
 		catch {destroy $cm}
 		menu $cm -postcommand "dsk_casdirs $p $cm 1 \
-			\{$entry delete 0 end; $entry insert end \list %d\]\}"
+			\{$entry delete 0 end; $entry insert end \[list %d\]\}"
 		incr i
 		if {$p == "/"} break
 	    }
@@ -316,7 +324,7 @@ proc dsk_copy_action {cmd} {
     set alist ""
     foreach f $tlist {
 	catch {set f [cb_tilde $f expand]}
-	if {[string index $f 0] != "/"} {
+	if {[string index $f 0] != "/" && ![regexp {:/} $f]} {
 	    set f [dsk_active dir]$f
 	}
 	set err [catch {set fl [glob [_make_fname_safe $f]]}]
@@ -324,6 +332,8 @@ proc dsk_copy_action {cmd} {
 	    foreach fe $fl {
 		lappend alist $fe
 	    }
+	} elseif {[regexp {:/} $f]} {
+	    lappend alist $f
 	} else {
 	    dsk_errbell
 	    cb_error "$f: no match!"
@@ -378,7 +388,7 @@ proc dsk_copy_action {cmd} {
 		return
 	    }
 	} elseif {$cmd == "copy"} {
-	    if ![file readable $file] {
+	    if {![file readable $file] && ![regexp {:/} $file]} {
 		cb_error "[file tail $file]:\nnot readable."
 		return
 	    }
