@@ -164,8 +164,12 @@ proc _dsk_cpanel_retrieveX {which offset maxBytes} {
 }
 
 proc _dsk_cpanel_color {frame default} {
+    global tkdesk
     
-    dskColorDialog $frame $default
+    if {$default == ""} {
+       set default $tkdesk(color,background)
+    }
+    tk_chooseColor -parent $frame -initialcolor $default
 }
 
 proc _dsk_cpanel_color_set {w dummy} {
