@@ -130,7 +130,7 @@ itcl_class dsk_Listbox {
 	#frame $frame.corner -width [expr $pad * 2 + 19]
 	#frame $frame.fhs
 
-	bindtags $frame.text "$frame.text all"
+	bindtags $frame.text "$frame.text MouseWheelEnabled all"
 	
         bind $frame.text <1> "
 	    focus [winfo toplevel $frame]
