@@ -649,3 +649,55 @@ proc dsk_casdirs_popup {menu id x y} {
 	dsk_popup {} $file $x $y
     }
 }
+
+#
+# -----------------------------------------------------------------------------
+#
+# Proc:		dsk_diff_files
+# Arg:		files - array of two file names
+# Returns: 	""
+# Desc:		Runs the diff command [tkdesk(cmd,diff)] on the two files
+# Side-FX:	Depends on the diff command used...
+#
+proc dsk_diff_files {{files ""}} {
+
+   global tkdesk
+
+   if {$files == ""} {
+      set files [dsk_active sel]
+   }
+
+   set numfiles [llength $files]
+
+   if {$numfiles == 0} {
+      set file1 [cb_fileSelector \
+      		-filter [string trimright [dsk_active dir] /]/* \
+		-label "First file for comparison:" -showall 1]
+      if {$file1 == ""} {
+         return
+      }
+      incr numfiles
+   } else {
+      set file1 [lindex $files 0]
+   }
+
+   if {$numfiles == 1} {
+      set file2 [cb_fileSelector \
+      		-filter [string trimright [dsk_active dir] /]/* \
+		-label "File to compare with $file1:" -showall 1]
+
+      if {$file2 == ""} {
+         return
+      }
+   } else {
+      set file2 [lindex $files 1]
+   }
+
+   if {[catch {set tkdesk(cmd,diff)}]} {
+      dsk_view diff $file1 $file2
+   } else {
+      eval [concat dsk_exec $tkdesk(cmd,diff) "\"$file1\"" "\"$file2\""]
+   }
+   return
+}
+
