@@ -805,7 +805,7 @@ proc find_dd_pkgcmd {dlb token} {
     set flist ""
     set list [$dlb get]
     foreach f $fl {
-	lappend flist [lindex [lindex $list $f] 0]
+	lappend flist [lindex [split [lindex $list $f] \t] 0]
     }
 
     set nfiles 0
