@@ -68,10 +68,15 @@ proc dsk_about {} {
     catch {$t.lLabel config -font -*-helvetica-medium-r-*-*-14-*}
     pack $t.lLabel -in $t.f1 -padx 8 -pady 8 -fill x -expand yes
 
-    image create bitmap welcome_bm -data $tkdesk(welcome_bm) -foreground blue3
-    label $t.lTkDesk -image welcome_bm
+    if {[file exists $tkdesk(library)/images/tkdesk_logo.ppm]} {
+        image create photo welcome_bm -file $tkdesk(library)/images/tkdesk_logo.ppm
+        label $t.lTkDesk -image welcome_bm -relief raised -bd 10
+    } else {
+        image create bitmap welcome_bm -data $tkdesk(welcome_bm) -foreground blue3
+        label $t.lTkDesk -image welcome_bm
+    }
     pack $t.lTkDesk -in $t.f1 -padx 6 -pady 2 -fill x -expand yes
-    #message $t.lVersion -text "Version $tkdesk(version), dated $tkdesk(date)\nCopyright (C) 1996, 1997 Christian Bolik\n\nTkDesk comes with ABSOLUTELY NO WARRANTY.\nSee menu entry Help/License for details." -aspect 1000 -justify center
+    #message $t.lVersion -text "Version $tkdesk(version), dated $tkdesk(date)\nCopyright (C) 1996 Christian Bolik\n\nTkDesk comes with ABSOLUTELY NO WARRANTY.\nSee menu entry Help/License for details." -aspect 1000 -justify center
     #message $t.lVersion -text "A File Manager for\nUnix and the X Window System\n\nVersion $tkdesk(version), dated $tkdesk(date)\n\nWritten by Christian Bolik\n($tkdesk(authormail))\n\nPlease send me a short mail and tell me what you\nthink about this program, and what you feel could be\nimproved or added. Thanks!\n" -aspect 1000 -justify center
     message $t.lVersion -text "A File Manager for\nUnix and the X Window System\nWritten by Christian Bolik\n\nVersion $tkdesk(version), dated $tkdesk(date)\n\nTkDesk is maintained by J. Chris Coppick\n($tkdesk(maintmail))\n\nPlease send a short email about what you\nthink about this program, and what you feel could be\nimproved or added. Thanks!\n" -aspect 1000 -justify center
     catch {$t.lVersion config -font -*-helvetica-medium-r-*-*-14-*}
@@ -89,7 +94,7 @@ proc dsk_about {} {
     cb_button $t.bMail -text " Mail... " \
 	    -command "dsk_mailbug \"About TkDesk $tkdesk(version)...\" {}"
     cb_button $t.bWeb -text " Web... " \
-	    -command {dsk_netscape url http://people.mainz.netsurf.de/~bolik/tkdesk/ window}
+	    -command {dsk_netscape url http://tkdesk.sourceforge.net/ window}
     
     pack $t.bOK $t.bLic $t.bMail $t.bWeb -in $t.fButtons -side left \
 	    -padx $tkdesk(pad) -pady $tkdesk(pad) -ipady 0
@@ -175,8 +180,8 @@ proc dsk_help {what} {
 	    set cbhm howto
 	}
 	"changes" {
-	    set nfile $tkdesk(library)/doc/CHANGES
-	    set tfile $tkdesk(library)/doc/CHANGES
+	    set nfile $tkdesk(library)/doc/ChangeLog
+	    set tfile $tkdesk(library)/doc/ChangeLog
 	}
 	"license" {
 	    set nfile $tkdesk(library)/doc/License
@@ -233,7 +238,7 @@ proc dsk_about_web {} {
     image create bitmap welcome_bm -data $tkdesk(welcome_bm) -foreground blue3
     label $t.lTkDesk -image welcome_bm
     pack $t.lTkDesk -in $t.f1 -padx 6 -pady 2 -fill x -expand yes
-    #message $t.lVersion -text "Version $tkdesk(version), dated $tkdesk(date)\nCopyright (C) 1996, 1997 Christian Bolik\n\nTkDesk comes with ABSOLUTELY NO WARRANTY.\nSee menu entry Help/License for details." -aspect 1000 -justify center
+    #message $t.lVersion -text "Version $tkdesk(version), dated $tkdesk(date)\nCopyright (C) 1996 Christian Bolik\n\nTkDesk comes with ABSOLUTELY NO WARRANTY.\nSee menu entry Help/License for details." -aspect 1000 -justify center
     message $t.lVersion -text "A File Manager for\nUnix and the X Window System\n\nVersion $tkdesk(version), dated $tkdesk(date)" -aspect 1000  -justify center
     catch {$t.lVersion config -font -*-helvetica-medium-o-*-*-14-*}
     pack $t.lVersion -in $t.f1 -padx 8 -pady 8 -fill x -expand yes
