@@ -73,7 +73,16 @@ proc dsk_popup {lbox file mx my {opt ""}} {
 	dsk_build_popup tkdesk(popup,directories) $file $lbox $mx $my $opt
     } elseif [file_executable $file] {
 	# EXECUTABLE
-	dsk_build_popup tkdesk(popup,executables) $file $lbox $mx $my $opt
+	if {$tkdesk(dot_regular)} {
+	    if {[file extension $file] == ""} {
+		dsk_build_popup tkdesk(popup,executables) \
+			$file $lbox $mx $my $opt
+	    } else {
+		dsk_build_popup tkdesk(popup,regulars) $file $lbox $mx $my $opt
+	    }
+	} else {
+	    dsk_build_popup tkdesk(popup,executables) $file $lbox $mx $my $opt
+	}
     } else {
 	# REGULAR (and others)
 	dsk_build_popup tkdesk(popup,regulars) $file $lbox $mx $my $opt
@@ -224,8 +233,15 @@ proc dsk_build_popup {poplist file lbox mx my {opt ""}} {
 			    set cascmd_dirs "dsk_cd %d 1"
 			}
 			"deskitem*" {
-			    .dsk_popup add command -label "Remove Item " \
-				    -command "catch \{[lindex $opt 1] delete\}"
+			    if {[info exists tkdesk(deskdir)] && [string first $tkdesk(deskdir) $file] == 0} {
+				.dsk_popup add command \
+					-label "Delete File & Item " \
+					-command "catch \{[lindex $opt 1] discard\}"
+			    } else {
+				.dsk_popup add command \
+					-label "Remove Item " \
+					-command "catch \{[lindex $opt 1] discard\}"
+			    }
 			    set cascmd_dirs "dsk_cd %d 1"
 			    set cascmd_mixed "dsk_cd %d 1"
 			}
