@@ -41,7 +41,8 @@
 #include <string.h>
 
 
-int get_port (char *key)
+int get_port (key)
+char *key;
 {
     DIR *dp;
     struct dirent *dir;
@@ -140,7 +141,7 @@ char *argv[];
 
     /* send key */
     write (s, key, strlen(key));
-    write (s, "\n", 2);
+    write (s, "\n", 1);
     if ((rc = read (s, buf, 256)) < 0) {
 	fprintf (stderr, "Oops, server rejected our key...\n");
 	return 4;
@@ -154,7 +155,7 @@ char *argv[];
 	    write (s, argv[i], strlen (argv[i]));
 	}
 	
-	write (s, "\n", 2);
+	write (s, "\n", 1);
     } else {
 
 	while ((c = fgetc (stdin)) != EOF)
